[Python-checkins] cpython: Bump Windows build to 3.5

zach.ware python-checkins at python.org
Mon Mar 17 21:58:01 CET 2014


http://hg.python.org/cpython/rev/e9f136c394e2
changeset:   89823:e9f136c394e2
user:        Zachary Ware <zachary.ware at gmail.com>
date:        Mon Mar 17 15:57:38 2014 -0500
summary:
  Bump Windows build to 3.5

files:
  PC/VS9.0/kill_python.c       |    14 +-
  PC/VS9.0/pyproject.vsprops   |     2 +-
  PC/example_nt/example.vcproj |     4 +-
  PC/pyconfig.h                |     4 +-
  PC/python3.def               |  1398 +++++++++++-----------
  PC/python3.mak               |    12 +-
  PC/python34gen.py            |     8 +-
  PC/python34stub.def          |     2 +-
  PCbuild/build_ssl.bat        |     4 +-
  PCbuild/kill_python.c        |    14 +-
  PCbuild/pyproject.props      |     4 +-
  PCbuild/readme.txt           |     2 +-
  12 files changed, 734 insertions(+), 734 deletions(-)


diff --git a/PC/VS9.0/kill_python.c b/PC/VS9.0/kill_python.c
--- a/PC/VS9.0/kill_python.c
+++ b/PC/VS9.0/kill_python.c
@@ -62,7 +62,7 @@
             continue;
 
         len = wcsnlen_s(me.szExePath, MAX_PATH) - KILL_PYTHON_EXE_LEN;
-        wcsncpy_s(path, MAX_PATH+1, me.szExePath, len); 
+        wcsncpy_s(path, MAX_PATH+1, me.szExePath, len);
 
         break;
 
@@ -80,8 +80,8 @@
      * looking for python processes.  When we find one, verify it lives
      * in the same directory we live in.  If it does, kill it.  If we're
      * unable to kill it, treat this as a fatal error and return 1.
-     * 
-     * The rationale behind this is that we're called at the start of the 
+     *
+     * The rationale behind this is that we're called at the start of the
      * build process on the basis that we'll take care of killing any
      * running instances, such that the build won't encounter permission
      * denied errors during linking. If we can't kill one of the processes,
@@ -104,11 +104,11 @@
     do {
 
         /*
-         * XXX TODO: if we really wanted to be fancy, we could check the 
+         * XXX TODO: if we really wanted to be fancy, we could check the
          * modules for all processes (not just the python[_d].exe ones)
-         * and see if any of our DLLs are loaded (i.e. python34[_d].dll),
+         * and see if any of our DLLs are loaded (i.e. python35[_d].dll),
          * as that would also inhibit our ability to rebuild the solution.
-         * Not worth loosing sleep over though; for now, a simple check 
+         * Not worth loosing sleep over though; for now, a simple check
          * for just the python executable should be sufficient.
          */
 
@@ -119,7 +119,7 @@
         /* It's a python process, so figure out which directory it's in... */
         hsm = CreateToolhelp32Snapshot(TH32CS_SNAPMODULE, pe.th32ProcessID);
         if (hsm == INVALID_HANDLE_VALUE)
-            /* 
+            /*
              * If our module snapshot fails (which will happen if we don't own
              * the process), just ignore it and continue.  (It seems different
              * versions of Windows return different values for GetLastError()
diff --git a/PC/VS9.0/pyproject.vsprops b/PC/VS9.0/pyproject.vsprops
--- a/PC/VS9.0/pyproject.vsprops
+++ b/PC/VS9.0/pyproject.vsprops
@@ -38,7 +38,7 @@
 	/>
 	<UserMacro
 		Name="PyDllName"
-		Value="python34"
+		Value="python35"
 	/>
 	<UserMacro
 		Name="PythonExe"
diff --git a/PC/example_nt/example.vcproj b/PC/example_nt/example.vcproj
--- a/PC/example_nt/example.vcproj
+++ b/PC/example_nt/example.vcproj
@@ -39,7 +39,7 @@
 			<Tool
 				Name="VCLinkerTool"
 				AdditionalOptions="/export:initexample"
-				AdditionalDependencies="odbc32.lib odbccp32.lib python34.lib"
+				AdditionalDependencies="odbc32.lib odbccp32.lib python35.lib"
 				OutputFile=".\Release/example.pyd"
 				LinkIncremental="1"
 				SuppressStartupBanner="TRUE"
@@ -105,7 +105,7 @@
 			<Tool
 				Name="VCLinkerTool"
 				AdditionalOptions="/export:initexample"
-				AdditionalDependencies="odbc32.lib odbccp32.lib python34_d.lib"
+				AdditionalDependencies="odbc32.lib odbccp32.lib python35_d.lib"
 				OutputFile=".\Debug/example_d.pyd"
 				LinkIncremental="1"
 				SuppressStartupBanner="TRUE"
diff --git a/PC/pyconfig.h b/PC/pyconfig.h
--- a/PC/pyconfig.h
+++ b/PC/pyconfig.h
@@ -322,11 +322,11 @@
 			their Makefile (other compilers are generally
 			taken care of by distutils.) */
 #			if defined(_DEBUG)
-#				pragma comment(lib,"python34_d.lib")
+#				pragma comment(lib,"python35_d.lib")
 #			elif defined(Py_LIMITED_API)
 #				pragma comment(lib,"python3.lib")
 #			else
-#				pragma comment(lib,"python34.lib")
+#				pragma comment(lib,"python35.lib")
 #			endif /* _DEBUG */
 #		endif /* _MSC_VER */
 #	endif /* Py_BUILD_CORE */
diff --git a/PC/python3.def b/PC/python3.def
--- a/PC/python3.def
+++ b/PC/python3.def
@@ -1,701 +1,701 @@
-; When changing this file, run python34gen.py
+; When changing this file, run python35gen.py
 LIBRARY	"python3"
 EXPORTS
-  PyArg_Parse=python34.PyArg_Parse
-  PyArg_ParseTuple=python34.PyArg_ParseTuple
-  PyArg_ParseTupleAndKeywords=python34.PyArg_ParseTupleAndKeywords
-  PyArg_UnpackTuple=python34.PyArg_UnpackTuple
-  PyArg_VaParse=python34.PyArg_VaParse
-  PyArg_VaParseTupleAndKeywords=python34.PyArg_VaParseTupleAndKeywords
-  PyArg_ValidateKeywordArguments=python34.PyArg_ValidateKeywordArguments
-  PyBaseObject_Type=python34.PyBaseObject_Type DATA
-  PyBool_FromLong=python34.PyBool_FromLong
-  PyBool_Type=python34.PyBool_Type DATA
-  PyByteArrayIter_Type=python34.PyByteArrayIter_Type DATA
-  PyByteArray_AsString=python34.PyByteArray_AsString
-  PyByteArray_Concat=python34.PyByteArray_Concat
-  PyByteArray_FromObject=python34.PyByteArray_FromObject
-  PyByteArray_FromStringAndSize=python34.PyByteArray_FromStringAndSize
-  PyByteArray_Resize=python34.PyByteArray_Resize
-  PyByteArray_Size=python34.PyByteArray_Size
-  PyByteArray_Type=python34.PyByteArray_Type DATA
-  PyBytesIter_Type=python34.PyBytesIter_Type DATA
-  PyBytes_AsString=python34.PyBytes_AsString
-  PyBytes_AsStringAndSize=python34.PyBytes_AsStringAndSize
-  PyBytes_Concat=python34.PyBytes_Concat
-  PyBytes_ConcatAndDel=python34.PyBytes_ConcatAndDel
-  PyBytes_DecodeEscape=python34.PyBytes_DecodeEscape
-  PyBytes_FromFormat=python34.PyBytes_FromFormat
-  PyBytes_FromFormatV=python34.PyBytes_FromFormatV
-  PyBytes_FromObject=python34.PyBytes_FromObject
-  PyBytes_FromString=python34.PyBytes_FromString
-  PyBytes_FromStringAndSize=python34.PyBytes_FromStringAndSize
-  PyBytes_Repr=python34.PyBytes_Repr
-  PyBytes_Size=python34.PyBytes_Size
-  PyBytes_Type=python34.PyBytes_Type DATA
-  PyCFunction_Call=python34.PyCFunction_Call
-  PyCFunction_ClearFreeList=python34.PyCFunction_ClearFreeList
-  PyCFunction_GetFlags=python34.PyCFunction_GetFlags
-  PyCFunction_GetFunction=python34.PyCFunction_GetFunction
-  PyCFunction_GetSelf=python34.PyCFunction_GetSelf
-  PyCFunction_New=python34.PyCFunction_New
-  PyCFunction_NewEx=python34.PyCFunction_NewEx
-  PyCFunction_Type=python34.PyCFunction_Type DATA
-  PyCallIter_New=python34.PyCallIter_New
-  PyCallIter_Type=python34.PyCallIter_Type DATA
-  PyCallable_Check=python34.PyCallable_Check
-  PyCapsule_GetContext=python34.PyCapsule_GetContext
-  PyCapsule_GetDestructor=python34.PyCapsule_GetDestructor
-  PyCapsule_GetName=python34.PyCapsule_GetName
-  PyCapsule_GetPointer=python34.PyCapsule_GetPointer
-  PyCapsule_Import=python34.PyCapsule_Import
-  PyCapsule_IsValid=python34.PyCapsule_IsValid
-  PyCapsule_New=python34.PyCapsule_New
-  PyCapsule_SetContext=python34.PyCapsule_SetContext
-  PyCapsule_SetDestructor=python34.PyCapsule_SetDestructor
-  PyCapsule_SetName=python34.PyCapsule_SetName
-  PyCapsule_SetPointer=python34.PyCapsule_SetPointer
-  PyCapsule_Type=python34.PyCapsule_Type DATA
-  PyClassMethodDescr_Type=python34.PyClassMethodDescr_Type DATA
-  PyCodec_BackslashReplaceErrors=python34.PyCodec_BackslashReplaceErrors
-  PyCodec_Decode=python34.PyCodec_Decode
-  PyCodec_Decoder=python34.PyCodec_Decoder
-  PyCodec_Encode=python34.PyCodec_Encode
-  PyCodec_Encoder=python34.PyCodec_Encoder
-  PyCodec_IgnoreErrors=python34.PyCodec_IgnoreErrors
-  PyCodec_IncrementalDecoder=python34.PyCodec_IncrementalDecoder
-  PyCodec_IncrementalEncoder=python34.PyCodec_IncrementalEncoder
-  PyCodec_KnownEncoding=python34.PyCodec_KnownEncoding
-  PyCodec_LookupError=python34.PyCodec_LookupError
-  PyCodec_Register=python34.PyCodec_Register
-  PyCodec_RegisterError=python34.PyCodec_RegisterError
-  PyCodec_ReplaceErrors=python34.PyCodec_ReplaceErrors
-  PyCodec_StreamReader=python34.PyCodec_StreamReader
-  PyCodec_StreamWriter=python34.PyCodec_StreamWriter
-  PyCodec_StrictErrors=python34.PyCodec_StrictErrors
-  PyCodec_XMLCharRefReplaceErrors=python34.PyCodec_XMLCharRefReplaceErrors
-  PyComplex_FromDoubles=python34.PyComplex_FromDoubles
-  PyComplex_ImagAsDouble=python34.PyComplex_ImagAsDouble
-  PyComplex_RealAsDouble=python34.PyComplex_RealAsDouble
-  PyComplex_Type=python34.PyComplex_Type DATA
-  PyDescr_NewClassMethod=python34.PyDescr_NewClassMethod
-  PyDescr_NewGetSet=python34.PyDescr_NewGetSet
-  PyDescr_NewMember=python34.PyDescr_NewMember
-  PyDescr_NewMethod=python34.PyDescr_NewMethod
-  PyDictItems_Type=python34.PyDictItems_Type DATA
-  PyDictIterItem_Type=python34.PyDictIterItem_Type DATA
-  PyDictIterKey_Type=python34.PyDictIterKey_Type DATA
-  PyDictIterValue_Type=python34.PyDictIterValue_Type DATA
-  PyDictKeys_Type=python34.PyDictKeys_Type DATA
-  PyDictProxy_New=python34.PyDictProxy_New
-  PyDictProxy_Type=python34.PyDictProxy_Type DATA
-  PyDictValues_Type=python34.PyDictValues_Type DATA
-  PyDict_Clear=python34.PyDict_Clear
-  PyDict_Contains=python34.PyDict_Contains
-  PyDict_Copy=python34.PyDict_Copy
-  PyDict_DelItem=python34.PyDict_DelItem
-  PyDict_DelItemString=python34.PyDict_DelItemString
-  PyDict_GetItem=python34.PyDict_GetItem
-  PyDict_GetItemString=python34.PyDict_GetItemString
-  PyDict_GetItemWithError=python34.PyDict_GetItemWithError
-  PyDict_Items=python34.PyDict_Items
-  PyDict_Keys=python34.PyDict_Keys
-  PyDict_Merge=python34.PyDict_Merge
-  PyDict_MergeFromSeq2=python34.PyDict_MergeFromSeq2
-  PyDict_New=python34.PyDict_New
-  PyDict_Next=python34.PyDict_Next
-  PyDict_SetItem=python34.PyDict_SetItem
-  PyDict_SetItemString=python34.PyDict_SetItemString
-  PyDict_Size=python34.PyDict_Size
-  PyDict_Type=python34.PyDict_Type DATA
-  PyDict_Update=python34.PyDict_Update
-  PyDict_Values=python34.PyDict_Values
-  PyEllipsis_Type=python34.PyEllipsis_Type DATA
-  PyEnum_Type=python34.PyEnum_Type DATA
-  PyErr_BadArgument=python34.PyErr_BadArgument
-  PyErr_BadInternalCall=python34.PyErr_BadInternalCall
-  PyErr_CheckSignals=python34.PyErr_CheckSignals
-  PyErr_Clear=python34.PyErr_Clear
-  PyErr_Display=python34.PyErr_Display
-  PyErr_ExceptionMatches=python34.PyErr_ExceptionMatches
-  PyErr_Fetch=python34.PyErr_Fetch
-  PyErr_Format=python34.PyErr_Format
-  PyErr_GivenExceptionMatches=python34.PyErr_GivenExceptionMatches
-  PyErr_NewException=python34.PyErr_NewException
-  PyErr_NewExceptionWithDoc=python34.PyErr_NewExceptionWithDoc
-  PyErr_NoMemory=python34.PyErr_NoMemory
-  PyErr_NormalizeException=python34.PyErr_NormalizeException
-  PyErr_Occurred=python34.PyErr_Occurred
-  PyErr_Print=python34.PyErr_Print
-  PyErr_PrintEx=python34.PyErr_PrintEx
-  PyErr_ProgramText=python34.PyErr_ProgramText
-  PyErr_Restore=python34.PyErr_Restore
-  PyErr_SetFromErrno=python34.PyErr_SetFromErrno
-  PyErr_SetFromErrnoWithFilename=python34.PyErr_SetFromErrnoWithFilename
-  PyErr_SetFromErrnoWithFilenameObject=python34.PyErr_SetFromErrnoWithFilenameObject
-  PyErr_SetInterrupt=python34.PyErr_SetInterrupt
-  PyErr_SetNone=python34.PyErr_SetNone
-  PyErr_SetObject=python34.PyErr_SetObject
-  PyErr_SetString=python34.PyErr_SetString
-  PyErr_SyntaxLocation=python34.PyErr_SyntaxLocation
-  PyErr_WarnEx=python34.PyErr_WarnEx
-  PyErr_WarnExplicit=python34.PyErr_WarnExplicit
-  PyErr_WarnFormat=python34.PyErr_WarnFormat
-  PyErr_WriteUnraisable=python34.PyErr_WriteUnraisable
-  PyEval_AcquireLock=python34.PyEval_AcquireLock
-  PyEval_AcquireThread=python34.PyEval_AcquireThread
-  PyEval_CallFunction=python34.PyEval_CallFunction
-  PyEval_CallMethod=python34.PyEval_CallMethod
-  PyEval_CallObjectWithKeywords=python34.PyEval_CallObjectWithKeywords
-  PyEval_EvalCode=python34.PyEval_EvalCode
-  PyEval_EvalCodeEx=python34.PyEval_EvalCodeEx
-  PyEval_EvalFrame=python34.PyEval_EvalFrame
-  PyEval_EvalFrameEx=python34.PyEval_EvalFrameEx
-  PyEval_GetBuiltins=python34.PyEval_GetBuiltins
-  PyEval_GetCallStats=python34.PyEval_GetCallStats
-  PyEval_GetFrame=python34.PyEval_GetFrame
-  PyEval_GetFuncDesc=python34.PyEval_GetFuncDesc
-  PyEval_GetFuncName=python34.PyEval_GetFuncName
-  PyEval_GetGlobals=python34.PyEval_GetGlobals
-  PyEval_GetLocals=python34.PyEval_GetLocals
-  PyEval_InitThreads=python34.PyEval_InitThreads
-  PyEval_ReInitThreads=python34.PyEval_ReInitThreads
-  PyEval_ReleaseLock=python34.PyEval_ReleaseLock
-  PyEval_ReleaseThread=python34.PyEval_ReleaseThread
-  PyEval_RestoreThread=python34.PyEval_RestoreThread
-  PyEval_SaveThread=python34.PyEval_SaveThread
-  PyEval_ThreadsInitialized=python34.PyEval_ThreadsInitialized
-  PyExc_ArithmeticError=python34.PyExc_ArithmeticError DATA
-  PyExc_AssertionError=python34.PyExc_AssertionError DATA
-  PyExc_AttributeError=python34.PyExc_AttributeError DATA
-  PyExc_BaseException=python34.PyExc_BaseException DATA
-  PyExc_BufferError=python34.PyExc_BufferError DATA
-  PyExc_BytesWarning=python34.PyExc_BytesWarning DATA
-  PyExc_DeprecationWarning=python34.PyExc_DeprecationWarning DATA
-  PyExc_EOFError=python34.PyExc_EOFError DATA
-  PyExc_EnvironmentError=python34.PyExc_EnvironmentError DATA
-  PyExc_Exception=python34.PyExc_Exception DATA
-  PyExc_FloatingPointError=python34.PyExc_FloatingPointError DATA
-  PyExc_FutureWarning=python34.PyExc_FutureWarning DATA
-  PyExc_GeneratorExit=python34.PyExc_GeneratorExit DATA
-  PyExc_IOError=python34.PyExc_IOError DATA
-  PyExc_ImportError=python34.PyExc_ImportError DATA
-  PyExc_ImportWarning=python34.PyExc_ImportWarning DATA
-  PyExc_IndentationError=python34.PyExc_IndentationError DATA
-  PyExc_IndexError=python34.PyExc_IndexError DATA
-  PyExc_KeyError=python34.PyExc_KeyError DATA
-  PyExc_KeyboardInterrupt=python34.PyExc_KeyboardInterrupt DATA
-  PyExc_LookupError=python34.PyExc_LookupError DATA
-  PyExc_MemoryError=python34.PyExc_MemoryError DATA
-  PyExc_MemoryErrorInst=python34.PyExc_MemoryErrorInst DATA
-  PyExc_NameError=python34.PyExc_NameError DATA
-  PyExc_NotImplementedError=python34.PyExc_NotImplementedError DATA
-  PyExc_OSError=python34.PyExc_OSError DATA
-  PyExc_OverflowError=python34.PyExc_OverflowError DATA
-  PyExc_PendingDeprecationWarning=python34.PyExc_PendingDeprecationWarning DATA
-  PyExc_RecursionErrorInst=python34.PyExc_RecursionErrorInst DATA
-  PyExc_ReferenceError=python34.PyExc_ReferenceError DATA
-  PyExc_RuntimeError=python34.PyExc_RuntimeError DATA
-  PyExc_RuntimeWarning=python34.PyExc_RuntimeWarning DATA
-  PyExc_StopIteration=python34.PyExc_StopIteration DATA
-  PyExc_SyntaxError=python34.PyExc_SyntaxError DATA
-  PyExc_SyntaxWarning=python34.PyExc_SyntaxWarning DATA
-  PyExc_SystemError=python34.PyExc_SystemError DATA
-  PyExc_SystemExit=python34.PyExc_SystemExit DATA
-  PyExc_TabError=python34.PyExc_TabError DATA
-  PyExc_TypeError=python34.PyExc_TypeError DATA
-  PyExc_UnboundLocalError=python34.PyExc_UnboundLocalError DATA
-  PyExc_UnicodeDecodeError=python34.PyExc_UnicodeDecodeError DATA
-  PyExc_UnicodeEncodeError=python34.PyExc_UnicodeEncodeError DATA
-  PyExc_UnicodeError=python34.PyExc_UnicodeError DATA
-  PyExc_UnicodeTranslateError=python34.PyExc_UnicodeTranslateError DATA
-  PyExc_UnicodeWarning=python34.PyExc_UnicodeWarning DATA
-  PyExc_UserWarning=python34.PyExc_UserWarning DATA
-  PyExc_ValueError=python34.PyExc_ValueError DATA
-  PyExc_Warning=python34.PyExc_Warning DATA
-  PyExc_ZeroDivisionError=python34.PyExc_ZeroDivisionError DATA
-  PyException_GetCause=python34.PyException_GetCause
-  PyException_GetContext=python34.PyException_GetContext
-  PyException_GetTraceback=python34.PyException_GetTraceback
-  PyException_SetCause=python34.PyException_SetCause
-  PyException_SetContext=python34.PyException_SetContext
-  PyException_SetTraceback=python34.PyException_SetTraceback
-  PyFile_FromFd=python34.PyFile_FromFd
-  PyFile_GetLine=python34.PyFile_GetLine
-  PyFile_WriteObject=python34.PyFile_WriteObject
-  PyFile_WriteString=python34.PyFile_WriteString
-  PyFilter_Type=python34.PyFilter_Type DATA
-  PyFloat_AsDouble=python34.PyFloat_AsDouble
-  PyFloat_FromDouble=python34.PyFloat_FromDouble
-  PyFloat_FromString=python34.PyFloat_FromString
-  PyFloat_GetInfo=python34.PyFloat_GetInfo
-  PyFloat_GetMax=python34.PyFloat_GetMax
-  PyFloat_GetMin=python34.PyFloat_GetMin
-  PyFloat_Type=python34.PyFloat_Type DATA
-  PyFrozenSet_New=python34.PyFrozenSet_New
-  PyFrozenSet_Type=python34.PyFrozenSet_Type DATA
-  PyGC_Collect=python34.PyGC_Collect
-  PyGILState_Ensure=python34.PyGILState_Ensure
-  PyGILState_GetThisThreadState=python34.PyGILState_GetThisThreadState
-  PyGILState_Release=python34.PyGILState_Release
-  PyGetSetDescr_Type=python34.PyGetSetDescr_Type DATA
-  PyImport_AddModule=python34.PyImport_AddModule
-  PyImport_AppendInittab=python34.PyImport_AppendInittab
-  PyImport_Cleanup=python34.PyImport_Cleanup
-  PyImport_ExecCodeModule=python34.PyImport_ExecCodeModule
-  PyImport_ExecCodeModuleEx=python34.PyImport_ExecCodeModuleEx
-  PyImport_ExecCodeModuleWithPathnames=python34.PyImport_ExecCodeModuleWithPathnames
-  PyImport_GetImporter=python34.PyImport_GetImporter
-  PyImport_GetMagicNumber=python34.PyImport_GetMagicNumber
-  PyImport_GetMagicTag=python34.PyImport_GetMagicTag
-  PyImport_GetModuleDict=python34.PyImport_GetModuleDict
-  PyImport_Import=python34.PyImport_Import
-  PyImport_ImportFrozenModule=python34.PyImport_ImportFrozenModule
-  PyImport_ImportModule=python34.PyImport_ImportModule
-  PyImport_ImportModuleLevel=python34.PyImport_ImportModuleLevel
-  PyImport_ImportModuleNoBlock=python34.PyImport_ImportModuleNoBlock
-  PyImport_ReloadModule=python34.PyImport_ReloadModule
-  PyInterpreterState_Clear=python34.PyInterpreterState_Clear
-  PyInterpreterState_Delete=python34.PyInterpreterState_Delete
-  PyInterpreterState_New=python34.PyInterpreterState_New
-  PyIter_Next=python34.PyIter_Next
-  PyListIter_Type=python34.PyListIter_Type DATA
-  PyListRevIter_Type=python34.PyListRevIter_Type DATA
-  PyList_Append=python34.PyList_Append
-  PyList_AsTuple=python34.PyList_AsTuple
-  PyList_GetItem=python34.PyList_GetItem
-  PyList_GetSlice=python34.PyList_GetSlice
-  PyList_Insert=python34.PyList_Insert
-  PyList_New=python34.PyList_New
-  PyList_Reverse=python34.PyList_Reverse
-  PyList_SetItem=python34.PyList_SetItem
-  PyList_SetSlice=python34.PyList_SetSlice
-  PyList_Size=python34.PyList_Size
-  PyList_Sort=python34.PyList_Sort
-  PyList_Type=python34.PyList_Type DATA
-  PyLongRangeIter_Type=python34.PyLongRangeIter_Type DATA
-  PyLong_AsDouble=python34.PyLong_AsDouble
-  PyLong_AsLong=python34.PyLong_AsLong
-  PyLong_AsLongAndOverflow=python34.PyLong_AsLongAndOverflow
-  PyLong_AsLongLong=python34.PyLong_AsLongLong
-  PyLong_AsLongLongAndOverflow=python34.PyLong_AsLongLongAndOverflow
-  PyLong_AsSize_t=python34.PyLong_AsSize_t
-  PyLong_AsSsize_t=python34.PyLong_AsSsize_t
-  PyLong_AsUnsignedLong=python34.PyLong_AsUnsignedLong
-  PyLong_AsUnsignedLongLong=python34.PyLong_AsUnsignedLongLong
-  PyLong_AsUnsignedLongLongMask=python34.PyLong_AsUnsignedLongLongMask
-  PyLong_AsUnsignedLongMask=python34.PyLong_AsUnsignedLongMask
-  PyLong_AsVoidPtr=python34.PyLong_AsVoidPtr
-  PyLong_FromDouble=python34.PyLong_FromDouble
-  PyLong_FromLong=python34.PyLong_FromLong
-  PyLong_FromLongLong=python34.PyLong_FromLongLong
-  PyLong_FromSize_t=python34.PyLong_FromSize_t
-  PyLong_FromSsize_t=python34.PyLong_FromSsize_t
-  PyLong_FromString=python34.PyLong_FromString
-  PyLong_FromUnsignedLong=python34.PyLong_FromUnsignedLong
-  PyLong_FromUnsignedLongLong=python34.PyLong_FromUnsignedLongLong
-  PyLong_FromVoidPtr=python34.PyLong_FromVoidPtr
-  PyLong_GetInfo=python34.PyLong_GetInfo
-  PyLong_Type=python34.PyLong_Type DATA
-  PyMap_Type=python34.PyMap_Type DATA
-  PyMapping_Check=python34.PyMapping_Check
-  PyMapping_GetItemString=python34.PyMapping_GetItemString
-  PyMapping_HasKey=python34.PyMapping_HasKey
-  PyMapping_HasKeyString=python34.PyMapping_HasKeyString
-  PyMapping_Items=python34.PyMapping_Items
-  PyMapping_Keys=python34.PyMapping_Keys
-  PyMapping_Length=python34.PyMapping_Length
-  PyMapping_SetItemString=python34.PyMapping_SetItemString
-  PyMapping_Size=python34.PyMapping_Size
-  PyMapping_Values=python34.PyMapping_Values
-  PyMem_Free=python34.PyMem_Free
-  PyMem_Malloc=python34.PyMem_Malloc
-  PyMem_Realloc=python34.PyMem_Realloc
-  PyMemberDescr_Type=python34.PyMemberDescr_Type DATA
-  PyMemoryView_FromObject=python34.PyMemoryView_FromObject
-  PyMemoryView_GetContiguous=python34.PyMemoryView_GetContiguous
-  PyMemoryView_Type=python34.PyMemoryView_Type DATA
-  PyMethodDescr_Type=python34.PyMethodDescr_Type DATA
-  PyModule_AddIntConstant=python34.PyModule_AddIntConstant
-  PyModule_AddObject=python34.PyModule_AddObject
-  PyModule_AddStringConstant=python34.PyModule_AddStringConstant
-  PyModule_Create2=python34.PyModule_Create2
-  PyModule_GetDef=python34.PyModule_GetDef
-  PyModule_GetDict=python34.PyModule_GetDict
-  PyModule_GetFilename=python34.PyModule_GetFilename
-  PyModule_GetFilenameObject=python34.PyModule_GetFilenameObject
-  PyModule_GetName=python34.PyModule_GetName
-  PyModule_GetState=python34.PyModule_GetState
-  PyModule_New=python34.PyModule_New
-  PyModule_Type=python34.PyModule_Type DATA
-  PyNullImporter_Type=python34.PyNullImporter_Type DATA
-  PyNumber_Absolute=python34.PyNumber_Absolute
-  PyNumber_Add=python34.PyNumber_Add
-  PyNumber_And=python34.PyNumber_And
-  PyNumber_AsSsize_t=python34.PyNumber_AsSsize_t
-  PyNumber_Check=python34.PyNumber_Check
-  PyNumber_Divmod=python34.PyNumber_Divmod
-  PyNumber_Float=python34.PyNumber_Float
-  PyNumber_FloorDivide=python34.PyNumber_FloorDivide
-  PyNumber_InPlaceAdd=python34.PyNumber_InPlaceAdd
-  PyNumber_InPlaceAnd=python34.PyNumber_InPlaceAnd
-  PyNumber_InPlaceFloorDivide=python34.PyNumber_InPlaceFloorDivide
-  PyNumber_InPlaceLshift=python34.PyNumber_InPlaceLshift
-  PyNumber_InPlaceMultiply=python34.PyNumber_InPlaceMultiply
-  PyNumber_InPlaceOr=python34.PyNumber_InPlaceOr
-  PyNumber_InPlacePower=python34.PyNumber_InPlacePower
-  PyNumber_InPlaceRemainder=python34.PyNumber_InPlaceRemainder
-  PyNumber_InPlaceRshift=python34.PyNumber_InPlaceRshift
-  PyNumber_InPlaceSubtract=python34.PyNumber_InPlaceSubtract
-  PyNumber_InPlaceTrueDivide=python34.PyNumber_InPlaceTrueDivide
-  PyNumber_InPlaceXor=python34.PyNumber_InPlaceXor
-  PyNumber_Index=python34.PyNumber_Index
-  PyNumber_Invert=python34.PyNumber_Invert
-  PyNumber_Long=python34.PyNumber_Long
-  PyNumber_Lshift=python34.PyNumber_Lshift
-  PyNumber_Multiply=python34.PyNumber_Multiply
-  PyNumber_Negative=python34.PyNumber_Negative
-  PyNumber_Or=python34.PyNumber_Or
-  PyNumber_Positive=python34.PyNumber_Positive
-  PyNumber_Power=python34.PyNumber_Power
-  PyNumber_Remainder=python34.PyNumber_Remainder
-  PyNumber_Rshift=python34.PyNumber_Rshift
-  PyNumber_Subtract=python34.PyNumber_Subtract
-  PyNumber_ToBase=python34.PyNumber_ToBase
-  PyNumber_TrueDivide=python34.PyNumber_TrueDivide
-  PyNumber_Xor=python34.PyNumber_Xor
-  PyOS_AfterFork=python34.PyOS_AfterFork
-  PyOS_InitInterrupts=python34.PyOS_InitInterrupts
-  PyOS_InputHook=python34.PyOS_InputHook DATA
-  PyOS_InterruptOccurred=python34.PyOS_InterruptOccurred
-  PyOS_ReadlineFunctionPointer=python34.PyOS_ReadlineFunctionPointer DATA
-  PyOS_double_to_string=python34.PyOS_double_to_string
-  PyOS_getsig=python34.PyOS_getsig
-  PyOS_mystricmp=python34.PyOS_mystricmp
-  PyOS_mystrnicmp=python34.PyOS_mystrnicmp
-  PyOS_setsig=python34.PyOS_setsig
-  PyOS_snprintf=python34.PyOS_snprintf
-  PyOS_string_to_double=python34.PyOS_string_to_double
-  PyOS_strtol=python34.PyOS_strtol
-  PyOS_strtoul=python34.PyOS_strtoul
-  PyOS_vsnprintf=python34.PyOS_vsnprintf
-  PyObject_ASCII=python34.PyObject_ASCII
-  PyObject_AsCharBuffer=python34.PyObject_AsCharBuffer
-  PyObject_AsFileDescriptor=python34.PyObject_AsFileDescriptor
-  PyObject_AsReadBuffer=python34.PyObject_AsReadBuffer
-  PyObject_AsWriteBuffer=python34.PyObject_AsWriteBuffer
-  PyObject_Bytes=python34.PyObject_Bytes
-  PyObject_Call=python34.PyObject_Call
-  PyObject_CallFunction=python34.PyObject_CallFunction
-  PyObject_CallFunctionObjArgs=python34.PyObject_CallFunctionObjArgs
-  PyObject_CallMethod=python34.PyObject_CallMethod
-  PyObject_CallMethodObjArgs=python34.PyObject_CallMethodObjArgs
-  PyObject_CallObject=python34.PyObject_CallObject
-  PyObject_CheckReadBuffer=python34.PyObject_CheckReadBuffer
-  PyObject_ClearWeakRefs=python34.PyObject_ClearWeakRefs
-  PyObject_DelItem=python34.PyObject_DelItem
-  PyObject_DelItemString=python34.PyObject_DelItemString
-  PyObject_Dir=python34.PyObject_Dir
-  PyObject_Format=python34.PyObject_Format
-  PyObject_Free=python34.PyObject_Free
-  PyObject_GC_Del=python34.PyObject_GC_Del
-  PyObject_GC_Track=python34.PyObject_GC_Track
-  PyObject_GC_UnTrack=python34.PyObject_GC_UnTrack
-  PyObject_GenericGetAttr=python34.PyObject_GenericGetAttr
-  PyObject_GenericSetAttr=python34.PyObject_GenericSetAttr
-  PyObject_GetAttr=python34.PyObject_GetAttr
-  PyObject_GetAttrString=python34.PyObject_GetAttrString
-  PyObject_GetItem=python34.PyObject_GetItem
-  PyObject_GetIter=python34.PyObject_GetIter
-  PyObject_HasAttr=python34.PyObject_HasAttr
-  PyObject_HasAttrString=python34.PyObject_HasAttrString
-  PyObject_Hash=python34.PyObject_Hash
-  PyObject_HashNotImplemented=python34.PyObject_HashNotImplemented
-  PyObject_Init=python34.PyObject_Init
-  PyObject_InitVar=python34.PyObject_InitVar
-  PyObject_IsInstance=python34.PyObject_IsInstance
-  PyObject_IsSubclass=python34.PyObject_IsSubclass
-  PyObject_IsTrue=python34.PyObject_IsTrue
-  PyObject_Length=python34.PyObject_Length
-  PyObject_Malloc=python34.PyObject_Malloc
-  PyObject_Not=python34.PyObject_Not
-  PyObject_Realloc=python34.PyObject_Realloc
-  PyObject_Repr=python34.PyObject_Repr
-  PyObject_RichCompare=python34.PyObject_RichCompare
-  PyObject_RichCompareBool=python34.PyObject_RichCompareBool
-  PyObject_SelfIter=python34.PyObject_SelfIter
-  PyObject_SetAttr=python34.PyObject_SetAttr
-  PyObject_SetAttrString=python34.PyObject_SetAttrString
-  PyObject_SetItem=python34.PyObject_SetItem
-  PyObject_Size=python34.PyObject_Size
-  PyObject_Str=python34.PyObject_Str
-  PyObject_Type=python34.PyObject_Type DATA
-  PyParser_SimpleParseFileFlags=python34.PyParser_SimpleParseFileFlags
-  PyParser_SimpleParseStringFlags=python34.PyParser_SimpleParseStringFlags
-  PyProperty_Type=python34.PyProperty_Type DATA
-  PyRangeIter_Type=python34.PyRangeIter_Type DATA
-  PyRange_Type=python34.PyRange_Type DATA
-  PyReversed_Type=python34.PyReversed_Type DATA
-  PySeqIter_New=python34.PySeqIter_New
-  PySeqIter_Type=python34.PySeqIter_Type DATA
-  PySequence_Check=python34.PySequence_Check
-  PySequence_Concat=python34.PySequence_Concat
-  PySequence_Contains=python34.PySequence_Contains
-  PySequence_Count=python34.PySequence_Count
-  PySequence_DelItem=python34.PySequence_DelItem
-  PySequence_DelSlice=python34.PySequence_DelSlice
-  PySequence_Fast=python34.PySequence_Fast
-  PySequence_GetItem=python34.PySequence_GetItem
-  PySequence_GetSlice=python34.PySequence_GetSlice
-  PySequence_In=python34.PySequence_In
-  PySequence_InPlaceConcat=python34.PySequence_InPlaceConcat
-  PySequence_InPlaceRepeat=python34.PySequence_InPlaceRepeat
-  PySequence_Index=python34.PySequence_Index
-  PySequence_Length=python34.PySequence_Length
-  PySequence_List=python34.PySequence_List
-  PySequence_Repeat=python34.PySequence_Repeat
-  PySequence_SetItem=python34.PySequence_SetItem
-  PySequence_SetSlice=python34.PySequence_SetSlice
-  PySequence_Size=python34.PySequence_Size
-  PySequence_Tuple=python34.PySequence_Tuple
-  PySetIter_Type=python34.PySetIter_Type DATA
-  PySet_Add=python34.PySet_Add
-  PySet_Clear=python34.PySet_Clear
-  PySet_Contains=python34.PySet_Contains
-  PySet_Discard=python34.PySet_Discard
-  PySet_New=python34.PySet_New
-  PySet_Pop=python34.PySet_Pop
-  PySet_Size=python34.PySet_Size
-  PySet_Type=python34.PySet_Type DATA
-  PySlice_GetIndices=python34.PySlice_GetIndices
-  PySlice_GetIndicesEx=python34.PySlice_GetIndicesEx
-  PySlice_New=python34.PySlice_New
-  PySlice_Type=python34.PySlice_Type DATA
-  PySortWrapper_Type=python34.PySortWrapper_Type DATA
-  PyState_FindModule=python34.PyState_FindModule
-  PyState_AddModule=python34.PyState_AddModule
-  PyState_RemoveModule=python34.PyState_RemoveModule
-  PyStructSequence_GetItem=python34.PyStructSequence_GetItem
-  PyStructSequence_New=python34.PyStructSequence_New
-  PyStructSequence_NewType=python34.PyStructSequence_NewType
-  PyStructSequence_SetItem=python34.PyStructSequence_SetItem
-  PySuper_Type=python34.PySuper_Type DATA
-  PySys_AddWarnOption=python34.PySys_AddWarnOption
-  PySys_AddWarnOptionUnicode=python34.PySys_AddWarnOptionUnicode
-  PySys_FormatStderr=python34.PySys_FormatStderr
-  PySys_FormatStdout=python34.PySys_FormatStdout
-  PySys_GetObject=python34.PySys_GetObject
-  PySys_HasWarnOptions=python34.PySys_HasWarnOptions
-  PySys_ResetWarnOptions=python34.PySys_ResetWarnOptions
-  PySys_SetArgv=python34.PySys_SetArgv
-  PySys_SetArgvEx=python34.PySys_SetArgvEx
-  PySys_SetObject=python34.PySys_SetObject
-  PySys_SetPath=python34.PySys_SetPath
-  PySys_WriteStderr=python34.PySys_WriteStderr
-  PySys_WriteStdout=python34.PySys_WriteStdout
-  PyThreadState_Clear=python34.PyThreadState_Clear
-  PyThreadState_Delete=python34.PyThreadState_Delete
-  PyThreadState_DeleteCurrent=python34.PyThreadState_DeleteCurrent
-  PyThreadState_Get=python34.PyThreadState_Get
-  PyThreadState_GetDict=python34.PyThreadState_GetDict
-  PyThreadState_New=python34.PyThreadState_New
-  PyThreadState_SetAsyncExc=python34.PyThreadState_SetAsyncExc
-  PyThreadState_Swap=python34.PyThreadState_Swap
-  PyTraceBack_Here=python34.PyTraceBack_Here
-  PyTraceBack_Print=python34.PyTraceBack_Print
-  PyTraceBack_Type=python34.PyTraceBack_Type DATA
-  PyTupleIter_Type=python34.PyTupleIter_Type DATA
-  PyTuple_ClearFreeList=python34.PyTuple_ClearFreeList
-  PyTuple_GetItem=python34.PyTuple_GetItem
-  PyTuple_GetSlice=python34.PyTuple_GetSlice
-  PyTuple_New=python34.PyTuple_New
-  PyTuple_Pack=python34.PyTuple_Pack
-  PyTuple_SetItem=python34.PyTuple_SetItem
-  PyTuple_Size=python34.PyTuple_Size
-  PyTuple_Type=python34.PyTuple_Type DATA
-  PyType_ClearCache=python34.PyType_ClearCache
-  PyType_FromSpec=python34.PyType_FromSpec
-  PyType_FromSpecWithBases=python34.PyType_FromSpecWithBases
-  PyType_GenericAlloc=python34.PyType_GenericAlloc
-  PyType_GenericNew=python34.PyType_GenericNew
-  PyType_GetFlags=python34.PyType_GetFlags
-  PyType_GetSlot=python34.PyType_GetSlot
-  PyType_IsSubtype=python34.PyType_IsSubtype
-  PyType_Modified=python34.PyType_Modified
-  PyType_Ready=python34.PyType_Ready
-  PyType_Type=python34.PyType_Type DATA
-  PyUnicodeDecodeError_Create=python34.PyUnicodeDecodeError_Create
-  PyUnicodeDecodeError_GetEncoding=python34.PyUnicodeDecodeError_GetEncoding
-  PyUnicodeDecodeError_GetEnd=python34.PyUnicodeDecodeError_GetEnd
-  PyUnicodeDecodeError_GetObject=python34.PyUnicodeDecodeError_GetObject
-  PyUnicodeDecodeError_GetReason=python34.PyUnicodeDecodeError_GetReason
-  PyUnicodeDecodeError_GetStart=python34.PyUnicodeDecodeError_GetStart
-  PyUnicodeDecodeError_SetEnd=python34.PyUnicodeDecodeError_SetEnd
-  PyUnicodeDecodeError_SetReason=python34.PyUnicodeDecodeError_SetReason
-  PyUnicodeDecodeError_SetStart=python34.PyUnicodeDecodeError_SetStart
-  PyUnicodeEncodeError_GetEncoding=python34.PyUnicodeEncodeError_GetEncoding
-  PyUnicodeEncodeError_GetEnd=python34.PyUnicodeEncodeError_GetEnd
-  PyUnicodeEncodeError_GetObject=python34.PyUnicodeEncodeError_GetObject
-  PyUnicodeEncodeError_GetReason=python34.PyUnicodeEncodeError_GetReason
-  PyUnicodeEncodeError_GetStart=python34.PyUnicodeEncodeError_GetStart
-  PyUnicodeEncodeError_SetEnd=python34.PyUnicodeEncodeError_SetEnd
-  PyUnicodeEncodeError_SetReason=python34.PyUnicodeEncodeError_SetReason
-  PyUnicodeEncodeError_SetStart=python34.PyUnicodeEncodeError_SetStart
-  PyUnicodeIter_Type=python34.PyUnicodeIter_Type DATA
-  PyUnicodeTranslateError_GetEnd=python34.PyUnicodeTranslateError_GetEnd
-  PyUnicodeTranslateError_GetObject=python34.PyUnicodeTranslateError_GetObject
-  PyUnicodeTranslateError_GetReason=python34.PyUnicodeTranslateError_GetReason
-  PyUnicodeTranslateError_GetStart=python34.PyUnicodeTranslateError_GetStart
-  PyUnicodeTranslateError_SetEnd=python34.PyUnicodeTranslateError_SetEnd
-  PyUnicodeTranslateError_SetReason=python34.PyUnicodeTranslateError_SetReason
-  PyUnicodeTranslateError_SetStart=python34.PyUnicodeTranslateError_SetStart
-  PyUnicode_Append=python34.PyUnicode_Append
-  PyUnicode_AppendAndDel=python34.PyUnicode_AppendAndDel
-  PyUnicode_AsASCIIString=python34.PyUnicode_AsASCIIString
-  PyUnicode_AsCharmapString=python34.PyUnicode_AsCharmapString
-  PyUnicode_AsDecodedObject=python34.PyUnicode_AsDecodedObject
-  PyUnicode_AsDecodedUnicode=python34.PyUnicode_AsDecodedUnicode
-  PyUnicode_AsEncodedObject=python34.PyUnicode_AsEncodedObject
-  PyUnicode_AsEncodedString=python34.PyUnicode_AsEncodedString
-  PyUnicode_AsEncodedUnicode=python34.PyUnicode_AsEncodedUnicode
-  PyUnicode_AsLatin1String=python34.PyUnicode_AsLatin1String
-  PyUnicode_AsRawUnicodeEscapeString=python34.PyUnicode_AsRawUnicodeEscapeString
-  PyUnicode_AsUTF16String=python34.PyUnicode_AsUTF16String
-  PyUnicode_AsUTF32String=python34.PyUnicode_AsUTF32String
-  PyUnicode_AsUTF8String=python34.PyUnicode_AsUTF8String
-  PyUnicode_AsUnicodeEscapeString=python34.PyUnicode_AsUnicodeEscapeString
-  PyUnicode_AsWideChar=python34.PyUnicode_AsWideChar
-  PyUnicode_ClearFreelist=python34.PyUnicode_ClearFreelist
-  PyUnicode_Compare=python34.PyUnicode_Compare
-  PyUnicode_Concat=python34.PyUnicode_Concat
-  PyUnicode_Contains=python34.PyUnicode_Contains
-  PyUnicode_Count=python34.PyUnicode_Count
-  PyUnicode_Decode=python34.PyUnicode_Decode
-  PyUnicode_DecodeASCII=python34.PyUnicode_DecodeASCII
-  PyUnicode_DecodeCharmap=python34.PyUnicode_DecodeCharmap
-  PyUnicode_DecodeFSDefault=python34.PyUnicode_DecodeFSDefault
-  PyUnicode_DecodeFSDefaultAndSize=python34.PyUnicode_DecodeFSDefaultAndSize
-  PyUnicode_DecodeLatin1=python34.PyUnicode_DecodeLatin1
-  PyUnicode_DecodeRawUnicodeEscape=python34.PyUnicode_DecodeRawUnicodeEscape
-  PyUnicode_DecodeUTF16=python34.PyUnicode_DecodeUTF16
-  PyUnicode_DecodeUTF16Stateful=python34.PyUnicode_DecodeUTF16Stateful
-  PyUnicode_DecodeUTF32=python34.PyUnicode_DecodeUTF32
-  PyUnicode_DecodeUTF32Stateful=python34.PyUnicode_DecodeUTF32Stateful
-  PyUnicode_DecodeUTF8=python34.PyUnicode_DecodeUTF8
-  PyUnicode_DecodeUTF8Stateful=python34.PyUnicode_DecodeUTF8Stateful
-  PyUnicode_DecodeUnicodeEscape=python34.PyUnicode_DecodeUnicodeEscape
-  PyUnicode_FSConverter=python34.PyUnicode_FSConverter
-  PyUnicode_FSDecoder=python34.PyUnicode_FSDecoder
-  PyUnicode_Find=python34.PyUnicode_Find
-  PyUnicode_Format=python34.PyUnicode_Format
-  PyUnicode_FromEncodedObject=python34.PyUnicode_FromEncodedObject
-  PyUnicode_FromFormat=python34.PyUnicode_FromFormat
-  PyUnicode_FromFormatV=python34.PyUnicode_FromFormatV
-  PyUnicode_FromObject=python34.PyUnicode_FromObject
-  PyUnicode_FromOrdinal=python34.PyUnicode_FromOrdinal
-  PyUnicode_FromString=python34.PyUnicode_FromString
-  PyUnicode_FromStringAndSize=python34.PyUnicode_FromStringAndSize
-  PyUnicode_FromWideChar=python34.PyUnicode_FromWideChar
-  PyUnicode_GetDefaultEncoding=python34.PyUnicode_GetDefaultEncoding
-  PyUnicode_GetSize=python34.PyUnicode_GetSize
-  PyUnicode_IsIdentifier=python34.PyUnicode_IsIdentifier
-  PyUnicode_Join=python34.PyUnicode_Join
-  PyUnicode_Partition=python34.PyUnicode_Partition
-  PyUnicode_RPartition=python34.PyUnicode_RPartition
-  PyUnicode_RSplit=python34.PyUnicode_RSplit
-  PyUnicode_Replace=python34.PyUnicode_Replace
-  PyUnicode_Resize=python34.PyUnicode_Resize
-  PyUnicode_RichCompare=python34.PyUnicode_RichCompare
-  PyUnicode_SetDefaultEncoding=python34.PyUnicode_SetDefaultEncoding
-  PyUnicode_Split=python34.PyUnicode_Split
-  PyUnicode_Splitlines=python34.PyUnicode_Splitlines
-  PyUnicode_Tailmatch=python34.PyUnicode_Tailmatch
-  PyUnicode_Translate=python34.PyUnicode_Translate
-  PyUnicode_BuildEncodingMap=python34.PyUnicode_BuildEncodingMap
-  PyUnicode_CompareWithASCIIString=python34.PyUnicode_CompareWithASCIIString
-  PyUnicode_DecodeUTF7=python34.PyUnicode_DecodeUTF7
-  PyUnicode_DecodeUTF7Stateful=python34.PyUnicode_DecodeUTF7Stateful
-  PyUnicode_EncodeFSDefault=python34.PyUnicode_EncodeFSDefault
-  PyUnicode_InternFromString=python34.PyUnicode_InternFromString
-  PyUnicode_InternImmortal=python34.PyUnicode_InternImmortal
-  PyUnicode_InternInPlace=python34.PyUnicode_InternInPlace
-  PyUnicode_Type=python34.PyUnicode_Type DATA
-  PyWeakref_GetObject=python34.PyWeakref_GetObject DATA
-  PyWeakref_NewProxy=python34.PyWeakref_NewProxy
-  PyWeakref_NewRef=python34.PyWeakref_NewRef
-  PyWrapperDescr_Type=python34.PyWrapperDescr_Type DATA
-  PyWrapper_New=python34.PyWrapper_New
-  PyZip_Type=python34.PyZip_Type DATA
-  Py_AddPendingCall=python34.Py_AddPendingCall
-  Py_AtExit=python34.Py_AtExit
-  Py_BuildValue=python34.Py_BuildValue
-  Py_CompileString=python34.Py_CompileString
-  Py_DecRef=python34.Py_DecRef
-  Py_EndInterpreter=python34.Py_EndInterpreter
-  Py_Exit=python34.Py_Exit
-  Py_FatalError=python34.Py_FatalError
-  Py_FileSystemDefaultEncoding=python34.Py_FileSystemDefaultEncoding DATA
-  Py_Finalize=python34.Py_Finalize
-  Py_GetBuildInfo=python34.Py_GetBuildInfo
-  Py_GetCompiler=python34.Py_GetCompiler
-  Py_GetCopyright=python34.Py_GetCopyright
-  Py_GetExecPrefix=python34.Py_GetExecPrefix
-  Py_GetPath=python34.Py_GetPath
-  Py_GetPlatform=python34.Py_GetPlatform
-  Py_GetPrefix=python34.Py_GetPrefix
-  Py_GetProgramFullPath=python34.Py_GetProgramFullPath
-  Py_GetProgramName=python34.Py_GetProgramName
-  Py_GetPythonHome=python34.Py_GetPythonHome
-  Py_GetRecursionLimit=python34.Py_GetRecursionLimit
-  Py_GetVersion=python34.Py_GetVersion
-  Py_HasFileSystemDefaultEncoding=python34.Py_HasFileSystemDefaultEncoding DATA
-  Py_IncRef=python34.Py_IncRef
-  Py_Initialize=python34.Py_Initialize
-  Py_InitializeEx=python34.Py_InitializeEx
-  Py_IsInitialized=python34.Py_IsInitialized
-  Py_Main=python34.Py_Main
-  Py_MakePendingCalls=python34.Py_MakePendingCalls
-  Py_NewInterpreter=python34.Py_NewInterpreter
-  Py_ReprEnter=python34.Py_ReprEnter
-  Py_ReprLeave=python34.Py_ReprLeave
-  Py_SetProgramName=python34.Py_SetProgramName
-  Py_SetPythonHome=python34.Py_SetPythonHome
-  Py_SetRecursionLimit=python34.Py_SetRecursionLimit
-  Py_SymtableString=python34.Py_SymtableString
-  Py_VaBuildValue=python34.Py_VaBuildValue
-  _PyErr_BadInternalCall=python34._PyErr_BadInternalCall
-  _PyObject_CallFunction_SizeT=python34._PyObject_CallFunction_SizeT
-  _PyObject_CallMethod_SizeT=python34._PyObject_CallMethod_SizeT
-  _PyObject_GC_Malloc=python34._PyObject_GC_Malloc
-  _PyObject_GC_New=python34._PyObject_GC_New
-  _PyObject_GC_NewVar=python34._PyObject_GC_NewVar
-  _PyObject_GC_Resize=python34._PyObject_GC_Resize
-  _PyObject_New=python34._PyObject_New
-  _PyObject_NewVar=python34._PyObject_NewVar
-  _PyState_AddModule=python34._PyState_AddModule
-  _PyThreadState_Init=python34._PyThreadState_Init
-  _PyThreadState_Prealloc=python34._PyThreadState_Prealloc
-  _PyTrash_delete_later=python34._PyTrash_delete_later DATA
-  _PyTrash_delete_nesting=python34._PyTrash_delete_nesting DATA
-  _PyTrash_deposit_object=python34._PyTrash_deposit_object
-  _PyTrash_destroy_chain=python34._PyTrash_destroy_chain
-  _PyWeakref_CallableProxyType=python34._PyWeakref_CallableProxyType DATA
-  _PyWeakref_ProxyType=python34._PyWeakref_ProxyType DATA
-  _PyWeakref_RefType=python34._PyWeakref_RefType DATA
-  _Py_BuildValue_SizeT=python34._Py_BuildValue_SizeT
-  _Py_CheckRecursionLimit=python34._Py_CheckRecursionLimit DATA
-  _Py_CheckRecursiveCall=python34._Py_CheckRecursiveCall
-  _Py_Dealloc=python34._Py_Dealloc
-  _Py_EllipsisObject=python34._Py_EllipsisObject DATA
-  _Py_FalseStruct=python34._Py_FalseStruct DATA
-  _Py_NoneStruct=python34._Py_NoneStruct DATA
-  _Py_NotImplementedStruct=python34._Py_NotImplementedStruct DATA
-  _Py_SwappedOp=python34._Py_SwappedOp DATA
-  _Py_TrueStruct=python34._Py_TrueStruct DATA
-  _Py_VaBuildValue_SizeT=python34._Py_VaBuildValue_SizeT
-  _PyArg_Parse_SizeT=python34._PyArg_Parse_SizeT
-  _PyArg_ParseTuple_SizeT=python34._PyArg_ParseTuple_SizeT
-  _PyArg_ParseTupleAndKeywords_SizeT=python34._PyArg_ParseTupleAndKeywords_SizeT
-  _PyArg_VaParse_SizeT=python34._PyArg_VaParse_SizeT
-  _PyArg_VaParseTupleAndKeywords_SizeT=python34._PyArg_VaParseTupleAndKeywords_SizeT
-  _Py_BuildValue_SizeT=python34._Py_BuildValue_SizeT
+  PyArg_Parse=python35.PyArg_Parse
+  PyArg_ParseTuple=python35.PyArg_ParseTuple
+  PyArg_ParseTupleAndKeywords=python35.PyArg_ParseTupleAndKeywords
+  PyArg_UnpackTuple=python35.PyArg_UnpackTuple
+  PyArg_VaParse=python35.PyArg_VaParse
+  PyArg_VaParseTupleAndKeywords=python35.PyArg_VaParseTupleAndKeywords
+  PyArg_ValidateKeywordArguments=python35.PyArg_ValidateKeywordArguments
+  PyBaseObject_Type=python35.PyBaseObject_Type DATA
+  PyBool_FromLong=python35.PyBool_FromLong
+  PyBool_Type=python35.PyBool_Type DATA
+  PyByteArrayIter_Type=python35.PyByteArrayIter_Type DATA
+  PyByteArray_AsString=python35.PyByteArray_AsString
+  PyByteArray_Concat=python35.PyByteArray_Concat
+  PyByteArray_FromObject=python35.PyByteArray_FromObject
+  PyByteArray_FromStringAndSize=python35.PyByteArray_FromStringAndSize
+  PyByteArray_Resize=python35.PyByteArray_Resize
+  PyByteArray_Size=python35.PyByteArray_Size
+  PyByteArray_Type=python35.PyByteArray_Type DATA
+  PyBytesIter_Type=python35.PyBytesIter_Type DATA
+  PyBytes_AsString=python35.PyBytes_AsString
+  PyBytes_AsStringAndSize=python35.PyBytes_AsStringAndSize
+  PyBytes_Concat=python35.PyBytes_Concat
+  PyBytes_ConcatAndDel=python35.PyBytes_ConcatAndDel
+  PyBytes_DecodeEscape=python35.PyBytes_DecodeEscape
+  PyBytes_FromFormat=python35.PyBytes_FromFormat
+  PyBytes_FromFormatV=python35.PyBytes_FromFormatV
+  PyBytes_FromObject=python35.PyBytes_FromObject
+  PyBytes_FromString=python35.PyBytes_FromString
+  PyBytes_FromStringAndSize=python35.PyBytes_FromStringAndSize
+  PyBytes_Repr=python35.PyBytes_Repr
+  PyBytes_Size=python35.PyBytes_Size
+  PyBytes_Type=python35.PyBytes_Type DATA
+  PyCFunction_Call=python35.PyCFunction_Call
+  PyCFunction_ClearFreeList=python35.PyCFunction_ClearFreeList
+  PyCFunction_GetFlags=python35.PyCFunction_GetFlags
+  PyCFunction_GetFunction=python35.PyCFunction_GetFunction
+  PyCFunction_GetSelf=python35.PyCFunction_GetSelf
+  PyCFunction_New=python35.PyCFunction_New
+  PyCFunction_NewEx=python35.PyCFunction_NewEx
+  PyCFunction_Type=python35.PyCFunction_Type DATA
+  PyCallIter_New=python35.PyCallIter_New
+  PyCallIter_Type=python35.PyCallIter_Type DATA
+  PyCallable_Check=python35.PyCallable_Check
+  PyCapsule_GetContext=python35.PyCapsule_GetContext
+  PyCapsule_GetDestructor=python35.PyCapsule_GetDestructor
+  PyCapsule_GetName=python35.PyCapsule_GetName
+  PyCapsule_GetPointer=python35.PyCapsule_GetPointer
+  PyCapsule_Import=python35.PyCapsule_Import
+  PyCapsule_IsValid=python35.PyCapsule_IsValid
+  PyCapsule_New=python35.PyCapsule_New
+  PyCapsule_SetContext=python35.PyCapsule_SetContext
+  PyCapsule_SetDestructor=python35.PyCapsule_SetDestructor
+  PyCapsule_SetName=python35.PyCapsule_SetName
+  PyCapsule_SetPointer=python35.PyCapsule_SetPointer
+  PyCapsule_Type=python35.PyCapsule_Type DATA
+  PyClassMethodDescr_Type=python35.PyClassMethodDescr_Type DATA
+  PyCodec_BackslashReplaceErrors=python35.PyCodec_BackslashReplaceErrors
+  PyCodec_Decode=python35.PyCodec_Decode
+  PyCodec_Decoder=python35.PyCodec_Decoder
+  PyCodec_Encode=python35.PyCodec_Encode
+  PyCodec_Encoder=python35.PyCodec_Encoder
+  PyCodec_IgnoreErrors=python35.PyCodec_IgnoreErrors
+  PyCodec_IncrementalDecoder=python35.PyCodec_IncrementalDecoder
+  PyCodec_IncrementalEncoder=python35.PyCodec_IncrementalEncoder
+  PyCodec_KnownEncoding=python35.PyCodec_KnownEncoding
+  PyCodec_LookupError=python35.PyCodec_LookupError
+  PyCodec_Register=python35.PyCodec_Register
+  PyCodec_RegisterError=python35.PyCodec_RegisterError
+  PyCodec_ReplaceErrors=python35.PyCodec_ReplaceErrors
+  PyCodec_StreamReader=python35.PyCodec_StreamReader
+  PyCodec_StreamWriter=python35.PyCodec_StreamWriter
+  PyCodec_StrictErrors=python35.PyCodec_StrictErrors
+  PyCodec_XMLCharRefReplaceErrors=python35.PyCodec_XMLCharRefReplaceErrors
+  PyComplex_FromDoubles=python35.PyComplex_FromDoubles
+  PyComplex_ImagAsDouble=python35.PyComplex_ImagAsDouble
+  PyComplex_RealAsDouble=python35.PyComplex_RealAsDouble
+  PyComplex_Type=python35.PyComplex_Type DATA
+  PyDescr_NewClassMethod=python35.PyDescr_NewClassMethod
+  PyDescr_NewGetSet=python35.PyDescr_NewGetSet
+  PyDescr_NewMember=python35.PyDescr_NewMember
+  PyDescr_NewMethod=python35.PyDescr_NewMethod
+  PyDictItems_Type=python35.PyDictItems_Type DATA
+  PyDictIterItem_Type=python35.PyDictIterItem_Type DATA
+  PyDictIterKey_Type=python35.PyDictIterKey_Type DATA
+  PyDictIterValue_Type=python35.PyDictIterValue_Type DATA
+  PyDictKeys_Type=python35.PyDictKeys_Type DATA
+  PyDictProxy_New=python35.PyDictProxy_New
+  PyDictProxy_Type=python35.PyDictProxy_Type DATA
+  PyDictValues_Type=python35.PyDictValues_Type DATA
+  PyDict_Clear=python35.PyDict_Clear
+  PyDict_Contains=python35.PyDict_Contains
+  PyDict_Copy=python35.PyDict_Copy
+  PyDict_DelItem=python35.PyDict_DelItem
+  PyDict_DelItemString=python35.PyDict_DelItemString
+  PyDict_GetItem=python35.PyDict_GetItem
+  PyDict_GetItemString=python35.PyDict_GetItemString
+  PyDict_GetItemWithError=python35.PyDict_GetItemWithError
+  PyDict_Items=python35.PyDict_Items
+  PyDict_Keys=python35.PyDict_Keys
+  PyDict_Merge=python35.PyDict_Merge
+  PyDict_MergeFromSeq2=python35.PyDict_MergeFromSeq2
+  PyDict_New=python35.PyDict_New
+  PyDict_Next=python35.PyDict_Next
+  PyDict_SetItem=python35.PyDict_SetItem
+  PyDict_SetItemString=python35.PyDict_SetItemString
+  PyDict_Size=python35.PyDict_Size
+  PyDict_Type=python35.PyDict_Type DATA
+  PyDict_Update=python35.PyDict_Update
+  PyDict_Values=python35.PyDict_Values
+  PyEllipsis_Type=python35.PyEllipsis_Type DATA
+  PyEnum_Type=python35.PyEnum_Type DATA
+  PyErr_BadArgument=python35.PyErr_BadArgument
+  PyErr_BadInternalCall=python35.PyErr_BadInternalCall
+  PyErr_CheckSignals=python35.PyErr_CheckSignals
+  PyErr_Clear=python35.PyErr_Clear
+  PyErr_Display=python35.PyErr_Display
+  PyErr_ExceptionMatches=python35.PyErr_ExceptionMatches
+  PyErr_Fetch=python35.PyErr_Fetch
+  PyErr_Format=python35.PyErr_Format
+  PyErr_GivenExceptionMatches=python35.PyErr_GivenExceptionMatches
+  PyErr_NewException=python35.PyErr_NewException
+  PyErr_NewExceptionWithDoc=python35.PyErr_NewExceptionWithDoc
+  PyErr_NoMemory=python35.PyErr_NoMemory
+  PyErr_NormalizeException=python35.PyErr_NormalizeException
+  PyErr_Occurred=python35.PyErr_Occurred
+  PyErr_Print=python35.PyErr_Print
+  PyErr_PrintEx=python35.PyErr_PrintEx
+  PyErr_ProgramText=python35.PyErr_ProgramText
+  PyErr_Restore=python35.PyErr_Restore
+  PyErr_SetFromErrno=python35.PyErr_SetFromErrno
+  PyErr_SetFromErrnoWithFilename=python35.PyErr_SetFromErrnoWithFilename
+  PyErr_SetFromErrnoWithFilenameObject=python35.PyErr_SetFromErrnoWithFilenameObject
+  PyErr_SetInterrupt=python35.PyErr_SetInterrupt
+  PyErr_SetNone=python35.PyErr_SetNone
+  PyErr_SetObject=python35.PyErr_SetObject
+  PyErr_SetString=python35.PyErr_SetString
+  PyErr_SyntaxLocation=python35.PyErr_SyntaxLocation
+  PyErr_WarnEx=python35.PyErr_WarnEx
+  PyErr_WarnExplicit=python35.PyErr_WarnExplicit
+  PyErr_WarnFormat=python35.PyErr_WarnFormat
+  PyErr_WriteUnraisable=python35.PyErr_WriteUnraisable
+  PyEval_AcquireLock=python35.PyEval_AcquireLock
+  PyEval_AcquireThread=python35.PyEval_AcquireThread
+  PyEval_CallFunction=python35.PyEval_CallFunction
+  PyEval_CallMethod=python35.PyEval_CallMethod
+  PyEval_CallObjectWithKeywords=python35.PyEval_CallObjectWithKeywords
+  PyEval_EvalCode=python35.PyEval_EvalCode
+  PyEval_EvalCodeEx=python35.PyEval_EvalCodeEx
+  PyEval_EvalFrame=python35.PyEval_EvalFrame
+  PyEval_EvalFrameEx=python35.PyEval_EvalFrameEx
+  PyEval_GetBuiltins=python35.PyEval_GetBuiltins
+  PyEval_GetCallStats=python35.PyEval_GetCallStats
+  PyEval_GetFrame=python35.PyEval_GetFrame
+  PyEval_GetFuncDesc=python35.PyEval_GetFuncDesc
+  PyEval_GetFuncName=python35.PyEval_GetFuncName
+  PyEval_GetGlobals=python35.PyEval_GetGlobals
+  PyEval_GetLocals=python35.PyEval_GetLocals
+  PyEval_InitThreads=python35.PyEval_InitThreads
+  PyEval_ReInitThreads=python35.PyEval_ReInitThreads
+  PyEval_ReleaseLock=python35.PyEval_ReleaseLock
+  PyEval_ReleaseThread=python35.PyEval_ReleaseThread
+  PyEval_RestoreThread=python35.PyEval_RestoreThread
+  PyEval_SaveThread=python35.PyEval_SaveThread
+  PyEval_ThreadsInitialized=python35.PyEval_ThreadsInitialized
+  PyExc_ArithmeticError=python35.PyExc_ArithmeticError DATA
+  PyExc_AssertionError=python35.PyExc_AssertionError DATA
+  PyExc_AttributeError=python35.PyExc_AttributeError DATA
+  PyExc_BaseException=python35.PyExc_BaseException DATA
+  PyExc_BufferError=python35.PyExc_BufferError DATA
+  PyExc_BytesWarning=python35.PyExc_BytesWarning DATA
+  PyExc_DeprecationWarning=python35.PyExc_DeprecationWarning DATA
+  PyExc_EOFError=python35.PyExc_EOFError DATA
+  PyExc_EnvironmentError=python35.PyExc_EnvironmentError DATA
+  PyExc_Exception=python35.PyExc_Exception DATA
+  PyExc_FloatingPointError=python35.PyExc_FloatingPointError DATA
+  PyExc_FutureWarning=python35.PyExc_FutureWarning DATA
+  PyExc_GeneratorExit=python35.PyExc_GeneratorExit DATA
+  PyExc_IOError=python35.PyExc_IOError DATA
+  PyExc_ImportError=python35.PyExc_ImportError DATA
+  PyExc_ImportWarning=python35.PyExc_ImportWarning DATA
+  PyExc_IndentationError=python35.PyExc_IndentationError DATA
+  PyExc_IndexError=python35.PyExc_IndexError DATA
+  PyExc_KeyError=python35.PyExc_KeyError DATA
+  PyExc_KeyboardInterrupt=python35.PyExc_KeyboardInterrupt DATA
+  PyExc_LookupError=python35.PyExc_LookupError DATA
+  PyExc_MemoryError=python35.PyExc_MemoryError DATA
+  PyExc_MemoryErrorInst=python35.PyExc_MemoryErrorInst DATA
+  PyExc_NameError=python35.PyExc_NameError DATA
+  PyExc_NotImplementedError=python35.PyExc_NotImplementedError DATA
+  PyExc_OSError=python35.PyExc_OSError DATA
+  PyExc_OverflowError=python35.PyExc_OverflowError DATA
+  PyExc_PendingDeprecationWarning=python35.PyExc_PendingDeprecationWarning DATA
+  PyExc_RecursionErrorInst=python35.PyExc_RecursionErrorInst DATA
+  PyExc_ReferenceError=python35.PyExc_ReferenceError DATA
+  PyExc_RuntimeError=python35.PyExc_RuntimeError DATA
+  PyExc_RuntimeWarning=python35.PyExc_RuntimeWarning DATA
+  PyExc_StopIteration=python35.PyExc_StopIteration DATA
+  PyExc_SyntaxError=python35.PyExc_SyntaxError DATA
+  PyExc_SyntaxWarning=python35.PyExc_SyntaxWarning DATA
+  PyExc_SystemError=python35.PyExc_SystemError DATA
+  PyExc_SystemExit=python35.PyExc_SystemExit DATA
+  PyExc_TabError=python35.PyExc_TabError DATA
+  PyExc_TypeError=python35.PyExc_TypeError DATA
+  PyExc_UnboundLocalError=python35.PyExc_UnboundLocalError DATA
+  PyExc_UnicodeDecodeError=python35.PyExc_UnicodeDecodeError DATA
+  PyExc_UnicodeEncodeError=python35.PyExc_UnicodeEncodeError DATA
+  PyExc_UnicodeError=python35.PyExc_UnicodeError DATA
+  PyExc_UnicodeTranslateError=python35.PyExc_UnicodeTranslateError DATA
+  PyExc_UnicodeWarning=python35.PyExc_UnicodeWarning DATA
+  PyExc_UserWarning=python35.PyExc_UserWarning DATA
+  PyExc_ValueError=python35.PyExc_ValueError DATA
+  PyExc_Warning=python35.PyExc_Warning DATA
+  PyExc_ZeroDivisionError=python35.PyExc_ZeroDivisionError DATA
+  PyException_GetCause=python35.PyException_GetCause
+  PyException_GetContext=python35.PyException_GetContext
+  PyException_GetTraceback=python35.PyException_GetTraceback
+  PyException_SetCause=python35.PyException_SetCause
+  PyException_SetContext=python35.PyException_SetContext
+  PyException_SetTraceback=python35.PyException_SetTraceback
+  PyFile_FromFd=python35.PyFile_FromFd
+  PyFile_GetLine=python35.PyFile_GetLine
+  PyFile_WriteObject=python35.PyFile_WriteObject
+  PyFile_WriteString=python35.PyFile_WriteString
+  PyFilter_Type=python35.PyFilter_Type DATA
+  PyFloat_AsDouble=python35.PyFloat_AsDouble
+  PyFloat_FromDouble=python35.PyFloat_FromDouble
+  PyFloat_FromString=python35.PyFloat_FromString
+  PyFloat_GetInfo=python35.PyFloat_GetInfo
+  PyFloat_GetMax=python35.PyFloat_GetMax
+  PyFloat_GetMin=python35.PyFloat_GetMin
+  PyFloat_Type=python35.PyFloat_Type DATA
+  PyFrozenSet_New=python35.PyFrozenSet_New
+  PyFrozenSet_Type=python35.PyFrozenSet_Type DATA
+  PyGC_Collect=python35.PyGC_Collect
+  PyGILState_Ensure=python35.PyGILState_Ensure
+  PyGILState_GetThisThreadState=python35.PyGILState_GetThisThreadState
+  PyGILState_Release=python35.PyGILState_Release
+  PyGetSetDescr_Type=python35.PyGetSetDescr_Type DATA
+  PyImport_AddModule=python35.PyImport_AddModule
+  PyImport_AppendInittab=python35.PyImport_AppendInittab
+  PyImport_Cleanup=python35.PyImport_Cleanup
+  PyImport_ExecCodeModule=python35.PyImport_ExecCodeModule
+  PyImport_ExecCodeModuleEx=python35.PyImport_ExecCodeModuleEx
+  PyImport_ExecCodeModuleWithPathnames=python35.PyImport_ExecCodeModuleWithPathnames
+  PyImport_GetImporter=python35.PyImport_GetImporter
+  PyImport_GetMagicNumber=python35.PyImport_GetMagicNumber
+  PyImport_GetMagicTag=python35.PyImport_GetMagicTag
+  PyImport_GetModuleDict=python35.PyImport_GetModuleDict
+  PyImport_Import=python35.PyImport_Import
+  PyImport_ImportFrozenModule=python35.PyImport_ImportFrozenModule
+  PyImport_ImportModule=python35.PyImport_ImportModule
+  PyImport_ImportModuleLevel=python35.PyImport_ImportModuleLevel
+  PyImport_ImportModuleNoBlock=python35.PyImport_ImportModuleNoBlock
+  PyImport_ReloadModule=python35.PyImport_ReloadModule
+  PyInterpreterState_Clear=python35.PyInterpreterState_Clear
+  PyInterpreterState_Delete=python35.PyInterpreterState_Delete
+  PyInterpreterState_New=python35.PyInterpreterState_New
+  PyIter_Next=python35.PyIter_Next
+  PyListIter_Type=python35.PyListIter_Type DATA
+  PyListRevIter_Type=python35.PyListRevIter_Type DATA
+  PyList_Append=python35.PyList_Append
+  PyList_AsTuple=python35.PyList_AsTuple
+  PyList_GetItem=python35.PyList_GetItem
+  PyList_GetSlice=python35.PyList_GetSlice
+  PyList_Insert=python35.PyList_Insert
+  PyList_New=python35.PyList_New
+  PyList_Reverse=python35.PyList_Reverse
+  PyList_SetItem=python35.PyList_SetItem
+  PyList_SetSlice=python35.PyList_SetSlice
+  PyList_Size=python35.PyList_Size
+  PyList_Sort=python35.PyList_Sort
+  PyList_Type=python35.PyList_Type DATA
+  PyLongRangeIter_Type=python35.PyLongRangeIter_Type DATA
+  PyLong_AsDouble=python35.PyLong_AsDouble
+  PyLong_AsLong=python35.PyLong_AsLong
+  PyLong_AsLongAndOverflow=python35.PyLong_AsLongAndOverflow
+  PyLong_AsLongLong=python35.PyLong_AsLongLong
+  PyLong_AsLongLongAndOverflow=python35.PyLong_AsLongLongAndOverflow
+  PyLong_AsSize_t=python35.PyLong_AsSize_t
+  PyLong_AsSsize_t=python35.PyLong_AsSsize_t
+  PyLong_AsUnsignedLong=python35.PyLong_AsUnsignedLong
+  PyLong_AsUnsignedLongLong=python35.PyLong_AsUnsignedLongLong
+  PyLong_AsUnsignedLongLongMask=python35.PyLong_AsUnsignedLongLongMask
+  PyLong_AsUnsignedLongMask=python35.PyLong_AsUnsignedLongMask
+  PyLong_AsVoidPtr=python35.PyLong_AsVoidPtr
+  PyLong_FromDouble=python35.PyLong_FromDouble
+  PyLong_FromLong=python35.PyLong_FromLong
+  PyLong_FromLongLong=python35.PyLong_FromLongLong
+  PyLong_FromSize_t=python35.PyLong_FromSize_t
+  PyLong_FromSsize_t=python35.PyLong_FromSsize_t
+  PyLong_FromString=python35.PyLong_FromString
+  PyLong_FromUnsignedLong=python35.PyLong_FromUnsignedLong
+  PyLong_FromUnsignedLongLong=python35.PyLong_FromUnsignedLongLong
+  PyLong_FromVoidPtr=python35.PyLong_FromVoidPtr
+  PyLong_GetInfo=python35.PyLong_GetInfo
+  PyLong_Type=python35.PyLong_Type DATA
+  PyMap_Type=python35.PyMap_Type DATA
+  PyMapping_Check=python35.PyMapping_Check
+  PyMapping_GetItemString=python35.PyMapping_GetItemString
+  PyMapping_HasKey=python35.PyMapping_HasKey
+  PyMapping_HasKeyString=python35.PyMapping_HasKeyString
+  PyMapping_Items=python35.PyMapping_Items
+  PyMapping_Keys=python35.PyMapping_Keys
+  PyMapping_Length=python35.PyMapping_Length
+  PyMapping_SetItemString=python35.PyMapping_SetItemString
+  PyMapping_Size=python35.PyMapping_Size
+  PyMapping_Values=python35.PyMapping_Values
+  PyMem_Free=python35.PyMem_Free
+  PyMem_Malloc=python35.PyMem_Malloc
+  PyMem_Realloc=python35.PyMem_Realloc
+  PyMemberDescr_Type=python35.PyMemberDescr_Type DATA
+  PyMemoryView_FromObject=python35.PyMemoryView_FromObject
+  PyMemoryView_GetContiguous=python35.PyMemoryView_GetContiguous
+  PyMemoryView_Type=python35.PyMemoryView_Type DATA
+  PyMethodDescr_Type=python35.PyMethodDescr_Type DATA
+  PyModule_AddIntConstant=python35.PyModule_AddIntConstant
+  PyModule_AddObject=python35.PyModule_AddObject
+  PyModule_AddStringConstant=python35.PyModule_AddStringConstant
+  PyModule_Create2=python35.PyModule_Create2
+  PyModule_GetDef=python35.PyModule_GetDef
+  PyModule_GetDict=python35.PyModule_GetDict
+  PyModule_GetFilename=python35.PyModule_GetFilename
+  PyModule_GetFilenameObject=python35.PyModule_GetFilenameObject
+  PyModule_GetName=python35.PyModule_GetName
+  PyModule_GetState=python35.PyModule_GetState
+  PyModule_New=python35.PyModule_New
+  PyModule_Type=python35.PyModule_Type DATA
+  PyNullImporter_Type=python35.PyNullImporter_Type DATA
+  PyNumber_Absolute=python35.PyNumber_Absolute
+  PyNumber_Add=python35.PyNumber_Add
+  PyNumber_And=python35.PyNumber_And
+  PyNumber_AsSsize_t=python35.PyNumber_AsSsize_t
+  PyNumber_Check=python35.PyNumber_Check
+  PyNumber_Divmod=python35.PyNumber_Divmod
+  PyNumber_Float=python35.PyNumber_Float
+  PyNumber_FloorDivide=python35.PyNumber_FloorDivide
+  PyNumber_InPlaceAdd=python35.PyNumber_InPlaceAdd
+  PyNumber_InPlaceAnd=python35.PyNumber_InPlaceAnd
+  PyNumber_InPlaceFloorDivide=python35.PyNumber_InPlaceFloorDivide
+  PyNumber_InPlaceLshift=python35.PyNumber_InPlaceLshift
+  PyNumber_InPlaceMultiply=python35.PyNumber_InPlaceMultiply
+  PyNumber_InPlaceOr=python35.PyNumber_InPlaceOr
+  PyNumber_InPlacePower=python35.PyNumber_InPlacePower
+  PyNumber_InPlaceRemainder=python35.PyNumber_InPlaceRemainder
+  PyNumber_InPlaceRshift=python35.PyNumber_InPlaceRshift
+  PyNumber_InPlaceSubtract=python35.PyNumber_InPlaceSubtract
+  PyNumber_InPlaceTrueDivide=python35.PyNumber_InPlaceTrueDivide
+  PyNumber_InPlaceXor=python35.PyNumber_InPlaceXor
+  PyNumber_Index=python35.PyNumber_Index
+  PyNumber_Invert=python35.PyNumber_Invert
+  PyNumber_Long=python35.PyNumber_Long
+  PyNumber_Lshift=python35.PyNumber_Lshift
+  PyNumber_Multiply=python35.PyNumber_Multiply
+  PyNumber_Negative=python35.PyNumber_Negative
+  PyNumber_Or=python35.PyNumber_Or
+  PyNumber_Positive=python35.PyNumber_Positive
+  PyNumber_Power=python35.PyNumber_Power
+  PyNumber_Remainder=python35.PyNumber_Remainder
+  PyNumber_Rshift=python35.PyNumber_Rshift
+  PyNumber_Subtract=python35.PyNumber_Subtract
+  PyNumber_ToBase=python35.PyNumber_ToBase
+  PyNumber_TrueDivide=python35.PyNumber_TrueDivide
+  PyNumber_Xor=python35.PyNumber_Xor
+  PyOS_AfterFork=python35.PyOS_AfterFork
+  PyOS_InitInterrupts=python35.PyOS_InitInterrupts
+  PyOS_InputHook=python35.PyOS_InputHook DATA
+  PyOS_InterruptOccurred=python35.PyOS_InterruptOccurred
+  PyOS_ReadlineFunctionPointer=python35.PyOS_ReadlineFunctionPointer DATA
+  PyOS_double_to_string=python35.PyOS_double_to_string
+  PyOS_getsig=python35.PyOS_getsig
+  PyOS_mystricmp=python35.PyOS_mystricmp
+  PyOS_mystrnicmp=python35.PyOS_mystrnicmp
+  PyOS_setsig=python35.PyOS_setsig
+  PyOS_snprintf=python35.PyOS_snprintf
+  PyOS_string_to_double=python35.PyOS_string_to_double
+  PyOS_strtol=python35.PyOS_strtol
+  PyOS_strtoul=python35.PyOS_strtoul
+  PyOS_vsnprintf=python35.PyOS_vsnprintf
+  PyObject_ASCII=python35.PyObject_ASCII
+  PyObject_AsCharBuffer=python35.PyObject_AsCharBuffer
+  PyObject_AsFileDescriptor=python35.PyObject_AsFileDescriptor
+  PyObject_AsReadBuffer=python35.PyObject_AsReadBuffer
+  PyObject_AsWriteBuffer=python35.PyObject_AsWriteBuffer
+  PyObject_Bytes=python35.PyObject_Bytes
+  PyObject_Call=python35.PyObject_Call
+  PyObject_CallFunction=python35.PyObject_CallFunction
+  PyObject_CallFunctionObjArgs=python35.PyObject_CallFunctionObjArgs
+  PyObject_CallMethod=python35.PyObject_CallMethod
+  PyObject_CallMethodObjArgs=python35.PyObject_CallMethodObjArgs
+  PyObject_CallObject=python35.PyObject_CallObject
+  PyObject_CheckReadBuffer=python35.PyObject_CheckReadBuffer
+  PyObject_ClearWeakRefs=python35.PyObject_ClearWeakRefs
+  PyObject_DelItem=python35.PyObject_DelItem
+  PyObject_DelItemString=python35.PyObject_DelItemString
+  PyObject_Dir=python35.PyObject_Dir
+  PyObject_Format=python35.PyObject_Format
+  PyObject_Free=python35.PyObject_Free
+  PyObject_GC_Del=python35.PyObject_GC_Del
+  PyObject_GC_Track=python35.PyObject_GC_Track
+  PyObject_GC_UnTrack=python35.PyObject_GC_UnTrack
+  PyObject_GenericGetAttr=python35.PyObject_GenericGetAttr
+  PyObject_GenericSetAttr=python35.PyObject_GenericSetAttr
+  PyObject_GetAttr=python35.PyObject_GetAttr
+  PyObject_GetAttrString=python35.PyObject_GetAttrString
+  PyObject_GetItem=python35.PyObject_GetItem
+  PyObject_GetIter=python35.PyObject_GetIter
+  PyObject_HasAttr=python35.PyObject_HasAttr
+  PyObject_HasAttrString=python35.PyObject_HasAttrString
+  PyObject_Hash=python35.PyObject_Hash
+  PyObject_HashNotImplemented=python35.PyObject_HashNotImplemented
+  PyObject_Init=python35.PyObject_Init
+  PyObject_InitVar=python35.PyObject_InitVar
+  PyObject_IsInstance=python35.PyObject_IsInstance
+  PyObject_IsSubclass=python35.PyObject_IsSubclass
+  PyObject_IsTrue=python35.PyObject_IsTrue
+  PyObject_Length=python35.PyObject_Length
+  PyObject_Malloc=python35.PyObject_Malloc
+  PyObject_Not=python35.PyObject_Not
+  PyObject_Realloc=python35.PyObject_Realloc
+  PyObject_Repr=python35.PyObject_Repr
+  PyObject_RichCompare=python35.PyObject_RichCompare
+  PyObject_RichCompareBool=python35.PyObject_RichCompareBool
+  PyObject_SelfIter=python35.PyObject_SelfIter
+  PyObject_SetAttr=python35.PyObject_SetAttr
+  PyObject_SetAttrString=python35.PyObject_SetAttrString
+  PyObject_SetItem=python35.PyObject_SetItem
+  PyObject_Size=python35.PyObject_Size
+  PyObject_Str=python35.PyObject_Str
+  PyObject_Type=python35.PyObject_Type DATA
+  PyParser_SimpleParseFileFlags=python35.PyParser_SimpleParseFileFlags
+  PyParser_SimpleParseStringFlags=python35.PyParser_SimpleParseStringFlags
+  PyProperty_Type=python35.PyProperty_Type DATA
+  PyRangeIter_Type=python35.PyRangeIter_Type DATA
+  PyRange_Type=python35.PyRange_Type DATA
+  PyReversed_Type=python35.PyReversed_Type DATA
+  PySeqIter_New=python35.PySeqIter_New
+  PySeqIter_Type=python35.PySeqIter_Type DATA
+  PySequence_Check=python35.PySequence_Check
+  PySequence_Concat=python35.PySequence_Concat
+  PySequence_Contains=python35.PySequence_Contains
+  PySequence_Count=python35.PySequence_Count
+  PySequence_DelItem=python35.PySequence_DelItem
+  PySequence_DelSlice=python35.PySequence_DelSlice
+  PySequence_Fast=python35.PySequence_Fast
+  PySequence_GetItem=python35.PySequence_GetItem
+  PySequence_GetSlice=python35.PySequence_GetSlice
+  PySequence_In=python35.PySequence_In
+  PySequence_InPlaceConcat=python35.PySequence_InPlaceConcat
+  PySequence_InPlaceRepeat=python35.PySequence_InPlaceRepeat
+  PySequence_Index=python35.PySequence_Index
+  PySequence_Length=python35.PySequence_Length
+  PySequence_List=python35.PySequence_List
+  PySequence_Repeat=python35.PySequence_Repeat
+  PySequence_SetItem=python35.PySequence_SetItem
+  PySequence_SetSlice=python35.PySequence_SetSlice
+  PySequence_Size=python35.PySequence_Size
+  PySequence_Tuple=python35.PySequence_Tuple
+  PySetIter_Type=python35.PySetIter_Type DATA
+  PySet_Add=python35.PySet_Add
+  PySet_Clear=python35.PySet_Clear
+  PySet_Contains=python35.PySet_Contains
+  PySet_Discard=python35.PySet_Discard
+  PySet_New=python35.PySet_New
+  PySet_Pop=python35.PySet_Pop
+  PySet_Size=python35.PySet_Size
+  PySet_Type=python35.PySet_Type DATA
+  PySlice_GetIndices=python35.PySlice_GetIndices
+  PySlice_GetIndicesEx=python35.PySlice_GetIndicesEx
+  PySlice_New=python35.PySlice_New
+  PySlice_Type=python35.PySlice_Type DATA
+  PySortWrapper_Type=python35.PySortWrapper_Type DATA
+  PyState_FindModule=python35.PyState_FindModule
+  PyState_AddModule=python35.PyState_AddModule
+  PyState_RemoveModule=python35.PyState_RemoveModule
+  PyStructSequence_GetItem=python35.PyStructSequence_GetItem
+  PyStructSequence_New=python35.PyStructSequence_New
+  PyStructSequence_NewType=python35.PyStructSequence_NewType
+  PyStructSequence_SetItem=python35.PyStructSequence_SetItem
+  PySuper_Type=python35.PySuper_Type DATA
+  PySys_AddWarnOption=python35.PySys_AddWarnOption
+  PySys_AddWarnOptionUnicode=python35.PySys_AddWarnOptionUnicode
+  PySys_FormatStderr=python35.PySys_FormatStderr
+  PySys_FormatStdout=python35.PySys_FormatStdout
+  PySys_GetObject=python35.PySys_GetObject
+  PySys_HasWarnOptions=python35.PySys_HasWarnOptions
+  PySys_ResetWarnOptions=python35.PySys_ResetWarnOptions
+  PySys_SetArgv=python35.PySys_SetArgv
+  PySys_SetArgvEx=python35.PySys_SetArgvEx
+  PySys_SetObject=python35.PySys_SetObject
+  PySys_SetPath=python35.PySys_SetPath
+  PySys_WriteStderr=python35.PySys_WriteStderr
+  PySys_WriteStdout=python35.PySys_WriteStdout
+  PyThreadState_Clear=python35.PyThreadState_Clear
+  PyThreadState_Delete=python35.PyThreadState_Delete
+  PyThreadState_DeleteCurrent=python35.PyThreadState_DeleteCurrent
+  PyThreadState_Get=python35.PyThreadState_Get
+  PyThreadState_GetDict=python35.PyThreadState_GetDict
+  PyThreadState_New=python35.PyThreadState_New
+  PyThreadState_SetAsyncExc=python35.PyThreadState_SetAsyncExc
+  PyThreadState_Swap=python35.PyThreadState_Swap
+  PyTraceBack_Here=python35.PyTraceBack_Here
+  PyTraceBack_Print=python35.PyTraceBack_Print
+  PyTraceBack_Type=python35.PyTraceBack_Type DATA
+  PyTupleIter_Type=python35.PyTupleIter_Type DATA
+  PyTuple_ClearFreeList=python35.PyTuple_ClearFreeList
+  PyTuple_GetItem=python35.PyTuple_GetItem
+  PyTuple_GetSlice=python35.PyTuple_GetSlice
+  PyTuple_New=python35.PyTuple_New
+  PyTuple_Pack=python35.PyTuple_Pack
+  PyTuple_SetItem=python35.PyTuple_SetItem
+  PyTuple_Size=python35.PyTuple_Size
+  PyTuple_Type=python35.PyTuple_Type DATA
+  PyType_ClearCache=python35.PyType_ClearCache
+  PyType_FromSpec=python35.PyType_FromSpec
+  PyType_FromSpecWithBases=python35.PyType_FromSpecWithBases
+  PyType_GenericAlloc=python35.PyType_GenericAlloc
+  PyType_GenericNew=python35.PyType_GenericNew
+  PyType_GetFlags=python35.PyType_GetFlags
+  PyType_GetSlot=python35.PyType_GetSlot
+  PyType_IsSubtype=python35.PyType_IsSubtype
+  PyType_Modified=python35.PyType_Modified
+  PyType_Ready=python35.PyType_Ready
+  PyType_Type=python35.PyType_Type DATA
+  PyUnicodeDecodeError_Create=python35.PyUnicodeDecodeError_Create
+  PyUnicodeDecodeError_GetEncoding=python35.PyUnicodeDecodeError_GetEncoding
+  PyUnicodeDecodeError_GetEnd=python35.PyUnicodeDecodeError_GetEnd
+  PyUnicodeDecodeError_GetObject=python35.PyUnicodeDecodeError_GetObject
+  PyUnicodeDecodeError_GetReason=python35.PyUnicodeDecodeError_GetReason
+  PyUnicodeDecodeError_GetStart=python35.PyUnicodeDecodeError_GetStart
+  PyUnicodeDecodeError_SetEnd=python35.PyUnicodeDecodeError_SetEnd
+  PyUnicodeDecodeError_SetReason=python35.PyUnicodeDecodeError_SetReason
+  PyUnicodeDecodeError_SetStart=python35.PyUnicodeDecodeError_SetStart
+  PyUnicodeEncodeError_GetEncoding=python35.PyUnicodeEncodeError_GetEncoding
+  PyUnicodeEncodeError_GetEnd=python35.PyUnicodeEncodeError_GetEnd
+  PyUnicodeEncodeError_GetObject=python35.PyUnicodeEncodeError_GetObject
+  PyUnicodeEncodeError_GetReason=python35.PyUnicodeEncodeError_GetReason
+  PyUnicodeEncodeError_GetStart=python35.PyUnicodeEncodeError_GetStart
+  PyUnicodeEncodeError_SetEnd=python35.PyUnicodeEncodeError_SetEnd
+  PyUnicodeEncodeError_SetReason=python35.PyUnicodeEncodeError_SetReason
+  PyUnicodeEncodeError_SetStart=python35.PyUnicodeEncodeError_SetStart
+  PyUnicodeIter_Type=python35.PyUnicodeIter_Type DATA
+  PyUnicodeTranslateError_GetEnd=python35.PyUnicodeTranslateError_GetEnd
+  PyUnicodeTranslateError_GetObject=python35.PyUnicodeTranslateError_GetObject
+  PyUnicodeTranslateError_GetReason=python35.PyUnicodeTranslateError_GetReason
+  PyUnicodeTranslateError_GetStart=python35.PyUnicodeTranslateError_GetStart
+  PyUnicodeTranslateError_SetEnd=python35.PyUnicodeTranslateError_SetEnd
+  PyUnicodeTranslateError_SetReason=python35.PyUnicodeTranslateError_SetReason
+  PyUnicodeTranslateError_SetStart=python35.PyUnicodeTranslateError_SetStart
+  PyUnicode_Append=python35.PyUnicode_Append
+  PyUnicode_AppendAndDel=python35.PyUnicode_AppendAndDel
+  PyUnicode_AsASCIIString=python35.PyUnicode_AsASCIIString
+  PyUnicode_AsCharmapString=python35.PyUnicode_AsCharmapString
+  PyUnicode_AsDecodedObject=python35.PyUnicode_AsDecodedObject
+  PyUnicode_AsDecodedUnicode=python35.PyUnicode_AsDecodedUnicode
+  PyUnicode_AsEncodedObject=python35.PyUnicode_AsEncodedObject
+  PyUnicode_AsEncodedString=python35.PyUnicode_AsEncodedString
+  PyUnicode_AsEncodedUnicode=python35.PyUnicode_AsEncodedUnicode
+  PyUnicode_AsLatin1String=python35.PyUnicode_AsLatin1String
+  PyUnicode_AsRawUnicodeEscapeString=python35.PyUnicode_AsRawUnicodeEscapeString
+  PyUnicode_AsUTF16String=python35.PyUnicode_AsUTF16String
+  PyUnicode_AsUTF32String=python35.PyUnicode_AsUTF32String
+  PyUnicode_AsUTF8String=python35.PyUnicode_AsUTF8String
+  PyUnicode_AsUnicodeEscapeString=python35.PyUnicode_AsUnicodeEscapeString
+  PyUnicode_AsWideChar=python35.PyUnicode_AsWideChar
+  PyUnicode_ClearFreelist=python35.PyUnicode_ClearFreelist
+  PyUnicode_Compare=python35.PyUnicode_Compare
+  PyUnicode_Concat=python35.PyUnicode_Concat
+  PyUnicode_Contains=python35.PyUnicode_Contains
+  PyUnicode_Count=python35.PyUnicode_Count
+  PyUnicode_Decode=python35.PyUnicode_Decode
+  PyUnicode_DecodeASCII=python35.PyUnicode_DecodeASCII
+  PyUnicode_DecodeCharmap=python35.PyUnicode_DecodeCharmap
+  PyUnicode_DecodeFSDefault=python35.PyUnicode_DecodeFSDefault
+  PyUnicode_DecodeFSDefaultAndSize=python35.PyUnicode_DecodeFSDefaultAndSize
+  PyUnicode_DecodeLatin1=python35.PyUnicode_DecodeLatin1
+  PyUnicode_DecodeRawUnicodeEscape=python35.PyUnicode_DecodeRawUnicodeEscape
+  PyUnicode_DecodeUTF16=python35.PyUnicode_DecodeUTF16
+  PyUnicode_DecodeUTF16Stateful=python35.PyUnicode_DecodeUTF16Stateful
+  PyUnicode_DecodeUTF32=python35.PyUnicode_DecodeUTF32
+  PyUnicode_DecodeUTF32Stateful=python35.PyUnicode_DecodeUTF32Stateful
+  PyUnicode_DecodeUTF8=python35.PyUnicode_DecodeUTF8
+  PyUnicode_DecodeUTF8Stateful=python35.PyUnicode_DecodeUTF8Stateful
+  PyUnicode_DecodeUnicodeEscape=python35.PyUnicode_DecodeUnicodeEscape
+  PyUnicode_FSConverter=python35.PyUnicode_FSConverter
+  PyUnicode_FSDecoder=python35.PyUnicode_FSDecoder
+  PyUnicode_Find=python35.PyUnicode_Find
+  PyUnicode_Format=python35.PyUnicode_Format
+  PyUnicode_FromEncodedObject=python35.PyUnicode_FromEncodedObject
+  PyUnicode_FromFormat=python35.PyUnicode_FromFormat
+  PyUnicode_FromFormatV=python35.PyUnicode_FromFormatV
+  PyUnicode_FromObject=python35.PyUnicode_FromObject
+  PyUnicode_FromOrdinal=python35.PyUnicode_FromOrdinal
+  PyUnicode_FromString=python35.PyUnicode_FromString
+  PyUnicode_FromStringAndSize=python35.PyUnicode_FromStringAndSize
+  PyUnicode_FromWideChar=python35.PyUnicode_FromWideChar
+  PyUnicode_GetDefaultEncoding=python35.PyUnicode_GetDefaultEncoding
+  PyUnicode_GetSize=python35.PyUnicode_GetSize
+  PyUnicode_IsIdentifier=python35.PyUnicode_IsIdentifier
+  PyUnicode_Join=python35.PyUnicode_Join
+  PyUnicode_Partition=python35.PyUnicode_Partition
+  PyUnicode_RPartition=python35.PyUnicode_RPartition
+  PyUnicode_RSplit=python35.PyUnicode_RSplit
+  PyUnicode_Replace=python35.PyUnicode_Replace
+  PyUnicode_Resize=python35.PyUnicode_Resize
+  PyUnicode_RichCompare=python35.PyUnicode_RichCompare
+  PyUnicode_SetDefaultEncoding=python35.PyUnicode_SetDefaultEncoding
+  PyUnicode_Split=python35.PyUnicode_Split
+  PyUnicode_Splitlines=python35.PyUnicode_Splitlines
+  PyUnicode_Tailmatch=python35.PyUnicode_Tailmatch
+  PyUnicode_Translate=python35.PyUnicode_Translate
+  PyUnicode_BuildEncodingMap=python35.PyUnicode_BuildEncodingMap
+  PyUnicode_CompareWithASCIIString=python35.PyUnicode_CompareWithASCIIString
+  PyUnicode_DecodeUTF7=python35.PyUnicode_DecodeUTF7
+  PyUnicode_DecodeUTF7Stateful=python35.PyUnicode_DecodeUTF7Stateful
+  PyUnicode_EncodeFSDefault=python35.PyUnicode_EncodeFSDefault
+  PyUnicode_InternFromString=python35.PyUnicode_InternFromString
+  PyUnicode_InternImmortal=python35.PyUnicode_InternImmortal
+  PyUnicode_InternInPlace=python35.PyUnicode_InternInPlace
+  PyUnicode_Type=python35.PyUnicode_Type DATA
+  PyWeakref_GetObject=python35.PyWeakref_GetObject DATA
+  PyWeakref_NewProxy=python35.PyWeakref_NewProxy
+  PyWeakref_NewRef=python35.PyWeakref_NewRef
+  PyWrapperDescr_Type=python35.PyWrapperDescr_Type DATA
+  PyWrapper_New=python35.PyWrapper_New
+  PyZip_Type=python35.PyZip_Type DATA
+  Py_AddPendingCall=python35.Py_AddPendingCall
+  Py_AtExit=python35.Py_AtExit
+  Py_BuildValue=python35.Py_BuildValue
+  Py_CompileString=python35.Py_CompileString
+  Py_DecRef=python35.Py_DecRef
+  Py_EndInterpreter=python35.Py_EndInterpreter
+  Py_Exit=python35.Py_Exit
+  Py_FatalError=python35.Py_FatalError
+  Py_FileSystemDefaultEncoding=python35.Py_FileSystemDefaultEncoding DATA
+  Py_Finalize=python35.Py_Finalize
+  Py_GetBuildInfo=python35.Py_GetBuildInfo
+  Py_GetCompiler=python35.Py_GetCompiler
+  Py_GetCopyright=python35.Py_GetCopyright
+  Py_GetExecPrefix=python35.Py_GetExecPrefix
+  Py_GetPath=python35.Py_GetPath
+  Py_GetPlatform=python35.Py_GetPlatform
+  Py_GetPrefix=python35.Py_GetPrefix
+  Py_GetProgramFullPath=python35.Py_GetProgramFullPath
+  Py_GetProgramName=python35.Py_GetProgramName
+  Py_GetPythonHome=python35.Py_GetPythonHome
+  Py_GetRecursionLimit=python35.Py_GetRecursionLimit
+  Py_GetVersion=python35.Py_GetVersion
+  Py_HasFileSystemDefaultEncoding=python35.Py_HasFileSystemDefaultEncoding DATA
+  Py_IncRef=python35.Py_IncRef
+  Py_Initialize=python35.Py_Initialize
+  Py_InitializeEx=python35.Py_InitializeEx
+  Py_IsInitialized=python35.Py_IsInitialized
+  Py_Main=python35.Py_Main
+  Py_MakePendingCalls=python35.Py_MakePendingCalls
+  Py_NewInterpreter=python35.Py_NewInterpreter
+  Py_ReprEnter=python35.Py_ReprEnter
+  Py_ReprLeave=python35.Py_ReprLeave
+  Py_SetProgramName=python35.Py_SetProgramName
+  Py_SetPythonHome=python35.Py_SetPythonHome
+  Py_SetRecursionLimit=python35.Py_SetRecursionLimit
+  Py_SymtableString=python35.Py_SymtableString
+  Py_VaBuildValue=python35.Py_VaBuildValue
+  _PyErr_BadInternalCall=python35._PyErr_BadInternalCall
+  _PyObject_CallFunction_SizeT=python35._PyObject_CallFunction_SizeT
+  _PyObject_CallMethod_SizeT=python35._PyObject_CallMethod_SizeT
+  _PyObject_GC_Malloc=python35._PyObject_GC_Malloc
+  _PyObject_GC_New=python35._PyObject_GC_New
+  _PyObject_GC_NewVar=python35._PyObject_GC_NewVar
+  _PyObject_GC_Resize=python35._PyObject_GC_Resize
+  _PyObject_New=python35._PyObject_New
+  _PyObject_NewVar=python35._PyObject_NewVar
+  _PyState_AddModule=python35._PyState_AddModule
+  _PyThreadState_Init=python35._PyThreadState_Init
+  _PyThreadState_Prealloc=python35._PyThreadState_Prealloc
+  _PyTrash_delete_later=python35._PyTrash_delete_later DATA
+  _PyTrash_delete_nesting=python35._PyTrash_delete_nesting DATA
+  _PyTrash_deposit_object=python35._PyTrash_deposit_object
+  _PyTrash_destroy_chain=python35._PyTrash_destroy_chain
+  _PyWeakref_CallableProxyType=python35._PyWeakref_CallableProxyType DATA
+  _PyWeakref_ProxyType=python35._PyWeakref_ProxyType DATA
+  _PyWeakref_RefType=python35._PyWeakref_RefType DATA
+  _Py_BuildValue_SizeT=python35._Py_BuildValue_SizeT
+  _Py_CheckRecursionLimit=python35._Py_CheckRecursionLimit DATA
+  _Py_CheckRecursiveCall=python35._Py_CheckRecursiveCall
+  _Py_Dealloc=python35._Py_Dealloc
+  _Py_EllipsisObject=python35._Py_EllipsisObject DATA
+  _Py_FalseStruct=python35._Py_FalseStruct DATA
+  _Py_NoneStruct=python35._Py_NoneStruct DATA
+  _Py_NotImplementedStruct=python35._Py_NotImplementedStruct DATA
+  _Py_SwappedOp=python35._Py_SwappedOp DATA
+  _Py_TrueStruct=python35._Py_TrueStruct DATA
+  _Py_VaBuildValue_SizeT=python35._Py_VaBuildValue_SizeT
+  _PyArg_Parse_SizeT=python35._PyArg_Parse_SizeT
+  _PyArg_ParseTuple_SizeT=python35._PyArg_ParseTuple_SizeT
+  _PyArg_ParseTupleAndKeywords_SizeT=python35._PyArg_ParseTupleAndKeywords_SizeT
+  _PyArg_VaParse_SizeT=python35._PyArg_VaParse_SizeT
+  _PyArg_VaParseTupleAndKeywords_SizeT=python35._PyArg_VaParseTupleAndKeywords_SizeT
+  _Py_BuildValue_SizeT=python35._Py_BuildValue_SizeT
diff --git a/PC/python3.mak b/PC/python3.mak
--- a/PC/python3.mak
+++ b/PC/python3.mak
@@ -1,14 +1,14 @@
-$(OutDir)python3.dll:	python3.def $(OutDir)python34stub.lib
-	cl /LD /Fe$(OutDir)python3.dll python3dll.c python3.def $(OutDir)python34stub.lib
+$(OutDir)python3.dll:	python3.def $(OutDir)python35stub.lib
+	cl /LD /Fe$(OutDir)python3.dll python3dll.c python3.def $(OutDir)python35stub.lib
 
-$(OutDir)python34stub.lib:	python34stub.def
-	lib /def:python34stub.def /out:$(OutDir)python34stub.lib /MACHINE:$(MACHINE)
+$(OutDir)python35stub.lib:	python35stub.def
+	lib /def:python35stub.def /out:$(OutDir)python35stub.lib /MACHINE:$(MACHINE)
 
 clean:
 	IF EXIST $(OutDir)python3.dll del $(OutDir)python3.dll
 	IF EXIST $(OutDir)python3.lib del $(OutDir)python3.lib
-	IF EXIST $(OutDir)python34stub.lib del $(OutDir)python34stub.lib
+	IF EXIST $(OutDir)python35stub.lib del $(OutDir)python35stub.lib
 	IF EXIST $(OutDir)python3.exp del $(OutDir)python3.exp
-	IF EXIST $(OutDir)python34stub.exp del $(OutDir)python34stub.exp
+	IF EXIST $(OutDir)python35stub.exp del $(OutDir)python35stub.exp
 
 rebuild: clean $(OutDir)python3.dll
diff --git a/PC/python34stub.def b/PC/python35stub.def
rename from PC/python34stub.def
rename to PC/python35stub.def
--- a/PC/python34stub.def
+++ b/PC/python35stub.def
@@ -1,4 +1,4 @@
-LIBRARY "python34"
+LIBRARY "python35"
 EXPORTS
 PyArg_Parse
 PyArg_ParseTuple
diff --git a/PCbuild/build_ssl.bat b/PCbuild/build_ssl.bat
--- a/PCbuild/build_ssl.bat
+++ b/PCbuild/build_ssl.bat
@@ -2,10 +2,10 @@
 if not defined HOST_PYTHON (
   if %1 EQU Debug (
     set HOST_PYTHON=python_d.exe
-    if not exist python34_d.dll exit 1
+    if not exist python35_d.dll exit 1
   ) ELSE (
     set HOST_PYTHON=python.exe
-    if not exist python34.dll exit 1
+    if not exist python35.dll exit 1
   )
 )
 %HOST_PYTHON% build_ssl.py %1 %2 %3
diff --git a/PCbuild/kill_python.c b/PCbuild/kill_python.c
--- a/PCbuild/kill_python.c
+++ b/PCbuild/kill_python.c
@@ -62,7 +62,7 @@
             continue;
 
         len = wcsnlen_s(me.szExePath, MAX_PATH) - KILL_PYTHON_EXE_LEN;
-        wcsncpy_s(path, MAX_PATH+1, me.szExePath, len); 
+        wcsncpy_s(path, MAX_PATH+1, me.szExePath, len);
 
         break;
 
@@ -80,8 +80,8 @@
      * looking for python processes.  When we find one, verify it lives
      * in the same directory we live in.  If it does, kill it.  If we're
      * unable to kill it, treat this as a fatal error and return 1.
-     * 
-     * The rationale behind this is that we're called at the start of the 
+     *
+     * The rationale behind this is that we're called at the start of the
      * build process on the basis that we'll take care of killing any
      * running instances, such that the build won't encounter permission
      * denied errors during linking. If we can't kill one of the processes,
@@ -104,11 +104,11 @@
     do {
 
         /*
-         * XXX TODO: if we really wanted to be fancy, we could check the 
+         * XXX TODO: if we really wanted to be fancy, we could check the
          * modules for all processes (not just the python[_d].exe ones)
-         * and see if any of our DLLs are loaded (i.e. python34[_d].dll),
+         * and see if any of our DLLs are loaded (i.e. python35[_d].dll),
          * as that would also inhibit our ability to rebuild the solution.
-         * Not worth loosing sleep over though; for now, a simple check 
+         * Not worth loosing sleep over though; for now, a simple check
          * for just the python executable should be sufficient.
          */
 
@@ -119,7 +119,7 @@
         /* It's a python process, so figure out which directory it's in... */
         hsm = CreateToolhelp32Snapshot(TH32CS_SNAPMODULE, pe.th32ProcessID);
         if (hsm == INVALID_HANDLE_VALUE)
-            /* 
+            /*
              * If our module snapshot fails (which will happen if we don't own
              * the process), just ignore it and continue.  (It seems different
              * versions of Windows return different values for GetLastError()
diff --git a/PCbuild/pyproject.props b/PCbuild/pyproject.props
--- a/PCbuild/pyproject.props
+++ b/PCbuild/pyproject.props
@@ -5,7 +5,7 @@
     <OutDir>$(SolutionDir)</OutDir>
     <IntDir>$(SolutionDir)$(PlatformName)-temp-$(Configuration)\$(ProjectName)\</IntDir>
     <LinkIncremental>false</LinkIncremental>
-  </PropertyGroup>  
+  </PropertyGroup>
   <PropertyGroup Condition="'$(Platform)'=='x64'">
     <_ProjectFileVersion>10.0.30319.1</_ProjectFileVersion>
     <_PropertySheetDisplayName>amd64</_PropertySheetDisplayName>
@@ -13,7 +13,7 @@
     <IntDir>$(SolutionDir)$(PlatformName)-temp-$(Configuration)\$(ProjectName)\</IntDir>
   </PropertyGroup>
   <PropertyGroup Label="UserMacros">
-    <PyDllName>python34$(PyDebugExt)</PyDllName>
+    <PyDllName>python35$(PyDebugExt)</PyDllName>
     <PythonExe>$(OutDir)python$(PyDebugExt).exe</PythonExe>
     <KillPythonExe>$(OutDir)kill_python$(PyDebugExt).exe</KillPythonExe>
     <externalsDir>..\..</externalsDir>
diff --git a/PCbuild/readme.txt b/PCbuild/readme.txt
--- a/PCbuild/readme.txt
+++ b/PCbuild/readme.txt
@@ -37,7 +37,7 @@
     Used to build Python with extra debugging capabilities, equivalent
     to using ./configure --with-pydebug on UNIX.  All binaries built
     using this configuration have "_d" added to their name:
-    python34_d.dll, python_d.exe, parser_d.pyd, and so on.  Both the
+    python35_d.dll, python_d.exe, parser_d.pyd, and so on.  Both the
     build and rt (run test) batch files in this directory accept a -d
     option for debug builds.  If you are building Python to help with
     development of CPython, you will most likely use this configuration.

diff --git a/PC/python34gen.py b/PC/python35gen.py
rename from PC/python34gen.py
rename to PC/python35gen.py
--- a/PC/python34gen.py
+++ b/PC/python35gen.py
@@ -1,9 +1,9 @@
 # Generate python34stub.def out of python3.def
 # The regular import library cannot be used,
 # since it doesn't provide the right symbols for
 # data forwarding
-out = open("python34stub.def", "w")
-out.write('LIBRARY "python34"\n')
+out = open("python35stub.def", "w")
+out.write('LIBRARY "python35"\n')
 out.write('EXPORTS\n')
 
 inp = open("python3.def")
@@ -14,7 +14,7 @@
 assert line.strip()=='EXPORTS'
 
 for line in inp:
-    # SYM1=python34.SYM2[ DATA]
+    # SYM1=python35.SYM2[ DATA]
     head, tail = line.split('.')
     if 'DATA' in tail:
         symbol, tail = tail.split(' ')
@@ -1,9 +1,9 @@
-# Generate python34stub.def out of python3.def
+# Generate python35stub.def out of python3.def
 # The regular import library cannot be used,
 # since it doesn't provide the right symbols for
-- 
Repository URL: http://hg.python.org/cpython


More information about the Python-checkins mailing list